// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO32_ADD_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO32_ADD_T32_H_

const byte kInstruction_add_al_r11_r13_r10_ASR_9[] = {
  0x0d, 0xeb, 0x6a, 0x2b // add al r11 r13 r10 ASR 9
};
const byte kInstruction_add_al_r7_r5_r2_ASR_2[] = {
  0x05, 0xeb, 0xa2, 0x07 // add al r7 r5 r2 ASR 2
};
const byte kInstruction_add_al_r5_r2_r11_LSR_5[] = {
  0x02, 0xeb, 0x5b, 0x15 // add al r5 r2 r11 LSR 5
};
const byte kInstruction_add_al_r14_r6_r10_LSR_32[] = {
  0x06, 0xeb, 0x1a, 0x0e // add al r14 r6 r10 LSR 32
};
const byte kInstruction_add_al_r9_r6_r3_LSR_13[] = {
  0x06, 0xeb, 0x53, 0x39 // add al r9 r6 r3 LSR 13
};
const byte kInstruction_add_al_r14_r4_r6_LSR_31[] = {
  0x04, 0xeb, 0xd6, 0x7e // add al r14 r4 r6 LSR 31
};
const byte kInstruction_add_al_r2_r1_r7_LSR_14[] = {
  0x01, 0xeb, 0x97, 0x32 // add al r2 r1 r7 LSR 14
};
const byte kInstruction_add_al_r2_r9_r12_LSR_24[] = {
  0x09, 0xeb, 0x1c, 0x62 // add al r2 r9 r12 LSR 24
};
const byte kInstruction_add_al_r10_r12_r4_ASR_2[] = {
  0x0c, 0xeb, 0xa4, 0x0a // add al r10 r12 r4 ASR 2
};
const byte kInstruction_add_al_r6_r10_r0_LSR_8[] = {
  0x0a, 0xeb, 0x10, 0x26 // add al r6 r10 r0 LSR 8
};
const byte kInstruction_add_al_r12_r11_r4_ASR_7[] = {
  0x0b, 0xeb, 0xe4, 0x1c // add al r12 r11 r4 ASR 7
};
const byte kInstruction_add_al_r9_r4_r8_ASR_27[] = {
  0x04, 0xeb, 0xe8, 0x69 // add al r9 r4 r8 ASR 27
};
const byte kInstruction_add_al_r2_r10_r11_ASR_1[] = {
  0x0a, 0xeb, 0x6b, 0x02 // add al r2 r10 r11 ASR 1
};
const byte kInstruction_add_al_r0_r2_r9_ASR_24[] = {
  0x02, 0xeb, 0x29, 0x60 // add al r0 r2 r9 ASR 24
};
const byte kInstruction_add_al_r11_r6_r14_ASR_31[] = {
  0x06, 0xeb, 0xee, 0x7b // add al r11 r6 r14 ASR 31
};
const byte kInstruction_add_al_r2_r14_r14_ASR_18[] = {
  0x0e, 0xeb, 0xae, 0x42 // add al r2 r14 r14 ASR 18
};
const byte kInstruction_add_al_r5_r7_r1_ASR_2[] = {
  0x07, 0xeb, 0xa1, 0x05 // add al r5 r7 r1 ASR 2
};
const byte kInstruction_add_al_r1_r14_r7_LSR_18[] = {
  0x0e, 0xeb, 0x97, 0x41 // add al r1 r14 r7 LSR 18
};
const byte kInstruction_add_al_r7_r7_r1_ASR_4[] = {
  0x07, 0xeb, 0x21, 0x17 // add al r7 r7 r1 ASR 4
};
const byte kInstruction_add_al_r14_r5_r12_LSR_1[] = {
  0x05, 0xeb, 0x5c, 0x0e // add al r14 r5 r12 LSR 1
};
const byte kInstruction_add_al_r2_r11_r10_ASR_23[] = {
  0x0b, 0xeb, 0xea, 0x52 // add al r2 r11 r10 ASR 23
};
const byte kInstruction_add_al_r5_r0_r10_ASR_3[] = {
  0x00, 0xeb, 0xea, 0x05 // add al r5 r0 r10 ASR 3
};
const byte kInstruction_add_al_r9_r13_r9_ASR_6[] = {
  0x0d, 0xeb, 0xa9, 0x19 // add al r9 r13 r9 ASR 6
};
const byte kInstruction_add_al_r6_r10_r13_ASR_24[] = {
  0x0a, 0xeb, 0x2d, 0x66 // add al r6 r10 r13 ASR 24
};
const byte kInstruction_add_al_r9_r3_r14_LSR_30[] = {
  0x03, 0xeb, 0x9e, 0x79 // add al r9 r3 r14 LSR 30
};
const byte kInstruction_add_al_r11_r14_r11_LSR_24[] = {
  0x0e, 0xeb, 0x1b, 0x6b // add al r11 r14 r11 LSR 24
};
const byte kInstruction_add_al_r11_r3_r4_ASR_7[] = {
  0x03, 0xeb, 0xe4, 0x1b // add al r11 r3 r4 ASR 7
};
const byte kInstruction_add_al_r14_r13_r10_ASR_1[] = {
  0x0d, 0xeb, 0x6a, 0x0e // add al r14 r13 r10 ASR 1
};
const byte kInstruction_add_al_r0_r9_r0_LSR_2[] = {
  0x09, 0xeb, 0x90, 0x00 // add al r0 r9 r0 LSR 2
};
const byte kInstruction_add_al_r2_r1_r7_ASR_15[] = {
  0x01, 0xeb, 0xe7, 0x32 // add al r2 r1 r7 ASR 15
};
const byte kInstruction_add_al_r8_r14_r5_LSR_27[] = {
  0x0e, 0xeb, 0xd5, 0x68 // add al r8 r14 r5 LSR 27
};
const byte kInstruction_add_al_r9_r14_r13_ASR_21[] = {
  0x0e, 0xeb, 0x6d, 0x59 // add al r9 r14 r13 ASR 21
};
const byte kInstruction_add_al_r11_r14_r14_ASR_3[] = {
  0x0e, 0xeb, 0xee, 0x0b // add al r11 r14 r14 ASR 3
};
const byte kInstruction_add_al_r6_r3_r6_LSR_23[] = {
  0x03, 0xeb, 0xd6, 0x56 // add al r6 r3 r6 LSR 23
};
const byte kInstruction_add_al_r14_r8_r11_LSR_6[] = {
  0x08, 0xeb, 0x9b, 0x1e // add al r14 r8 r11 LSR 6
};
const byte kInstruction_add_al_r5_r3_r3_LSR_8[] = {
  0x03, 0xeb, 0x13, 0x25 // add al r5 r3 r3 LSR 8
};
const byte kInstruction_add_al_r12_r6_r1_LSR_6[] = {
  0x06, 0xeb, 0x91, 0x1c // add al r12 r6 r1 LSR 6
};
const byte kInstruction_add_al_r5_r0_r9_LSR_30[] = {
  0x00, 0xeb, 0x99, 0x75 // add al r5 r0 r9 LSR 30
};
const byte kInstruction_add_al_r4_r9_r3_ASR_17[] = {
  0x09, 0xeb, 0x63, 0x44 // add al r4 r9 r3 ASR 17
};
const byte kInstruction_add_al_r12_r2_r4_ASR_20[] = {
  0x02, 0xeb, 0x24, 0x5c // add al r12 r2 r4 ASR 20
};
const byte kInstruction_add_al_r2_r9_r13_ASR_25[] = {
  0x09, 0xeb, 0x6d, 0x62 // add al r2 r9 r13 ASR 25
};
const byte kInstruction_add_al_r11_r5_r12_LSR_10[] = {
  0x05, 0xeb, 0x9c, 0x2b // add al r11 r5 r12 LSR 10
};
const byte kInstruction_add_al_r4_r13_r12_LSR_22[] = {
  0x0d, 0xeb, 0x9c, 0x54 // add al r4 r13 r12 LSR 22
};
const byte kInstruction_add_al_r2_r4_r6_LSR_11[] = {
  0x04, 0xeb, 0xd6, 0x22 // add al r2 r4 r6 LSR 11
};
const byte kInstruction_add_al_r8_r4_r1_LSR_22[] = {
  0x04, 0xeb, 0x91, 0x58 // add al r8 r4 r1 LSR 22
};
const byte kInstruction_add_al_r6_r12_r10_LSR_31[] = {
  0x0c, 0xeb, 0xda, 0x76 // add al r6 r12 r10 LSR 31
};
const byte kInstruction_add_al_r10_r0_r2_ASR_7[] = {
  0x00, 0xeb, 0xe2, 0x1a // add al r10 r0 r2 ASR 7
};
const byte kInstruction_add_al_r14_r6_r13_ASR_21[] = {
  0x06, 0xeb, 0x6d, 0x5e // add al r14 r6 r13 ASR 21
};
const byte kInstruction_add_al_r7_r14_r13_LSR_4[] = {
  0x0e, 0xeb, 0x1d, 0x17 // add al r7 r14 r13 LSR 4
};
const byte kInstruction_add_al_r1_r10_r12_ASR_2[] = {
  0x0a, 0xeb, 0xac, 0x01 // add al r1 r10 r12 ASR 2
};
const byte kInstruction_add_al_r0_r2_r10_LSR_7[] = {
  0x02, 0xeb, 0xda, 0x10 // add al r0 r2 r10 LSR 7
};
const byte kInstruction_add_al_r0_r1_r11_LSR_17[] = {
  0x01, 0xeb, 0x5b, 0x40 // add al r0 r1 r11 LSR 17
};
const byte kInstruction_add_al_r4_r13_r2_ASR_25[] = {
  0x0d, 0xeb, 0x62, 0x64 // add al r4 r13 r2 ASR 25
};
const byte kInstruction_add_al_r1_r4_r14_LSR_7[] = {
  0x04, 0xeb, 0xde, 0x11 // add al r1 r4 r14 LSR 7
};
const byte kInstruction_add_al_r5_r8_r4_ASR_19[] = {
  0x08, 0xeb, 0xe4, 0x45 // add al r5 r8 r4 ASR 19
};
const byte kInstruction_add_al_r4_r3_r8_ASR_12[] = {
  0x03, 0xeb, 0x28, 0x34 // add al r4 r3 r8 ASR 12
};
const byte kInstruction_add_al_r2_r4_r13_ASR_12[] = {
  0x04, 0xeb, 0x2d, 0x32 // add al r2 r4 r13 ASR 12
};
const byte kInstruction_add_al_r8_r9_r2_LSR_20[] = {
  0x09, 0xeb, 0x12, 0x58 // add al r8 r9 r2 LSR 20
};
const byte kInstruction_add_al_r10_r6_r3_ASR_21[] = {
  0x06, 0xeb, 0x63, 0x5a // add al r10 r6 r3 ASR 21
};
const byte kInstruction_add_al_r2_r7_r7_ASR_3[] = {
  0x07, 0xeb, 0xe7, 0x02 // add al r2 r7 r7 ASR 3
};
const byte kInstruction_add_al_r8_r7_r7_LSR_19[] = {
  0x07, 0xeb, 0xd7, 0x48 // add al r8 r7 r7 LSR 19
};
const byte kInstruction_add_al_r7_r9_r4_LSR_3[] = {
  0x09, 0xeb, 0xd4, 0x07 // add al r7 r9 r4 LSR 3
};
const byte kInstruction_add_al_r1_r7_r3_ASR_2[] = {
  0x07, 0xeb, 0xa3, 0x01 // add al r1 r7 r3 ASR 2
};
const byte kInstruction_add_al_r1_r2_r3_ASR_5[] = {
  0x02, 0xeb, 0x63, 0x11 // add al r1 r2 r3 ASR 5
};
const byte kInstruction_add_al_r12_r4_r1_ASR_5[] = {
  0x04, 0xeb, 0x61, 0x1c // add al r12 r4 r1 ASR 5
};
const byte kInstruction_add_al_r4_r2_r10_ASR_1[] = {
  0x02, 0xeb, 0x6a, 0x04 // add al r4 r2 r10 ASR 1
};
const byte kInstruction_add_al_r10_r5_r11_LSR_3[] = {
  0x05, 0xeb, 0xdb, 0x0a // add al r10 r5 r11 LSR 3
};
const byte kInstruction_add_al_r5_r9_r1_ASR_8[] = {
  0x09, 0xeb, 0x21, 0x25 // add al r5 r9 r1 ASR 8
};
const byte kInstruction_add_al_r6_r11_r3_LSR_28[] = {
  0x0b, 0xeb, 0x13, 0x76 // add al r6 r11 r3 LSR 28
};
const byte kInstruction_add_al_r9_r13_r6_LSR_22[] = {
  0x0d, 0xeb, 0x96, 0x59 // add al r9 r13 r6 LSR 22
};
const byte kInstruction_add_al_r10_r13_r1_LSR_30[] = {
  0x0d, 0xeb, 0x91, 0x7a // add al r10 r13 r1 LSR 30
};
const byte kInstruction_add_al_r9_r1_r4_ASR_26[] = {
  0x01, 0xeb, 0xa4, 0x69 // add al r9 r1 r4 ASR 26
};
const byte kInstruction_add_al_r4_r4_r4_ASR_21[] = {
  0x04, 0xeb, 0x64, 0x54 // add al r4 r4 r4 ASR 21
};
const byte kInstruction_add_al_r9_r5_r11_ASR_19[] = {
  0x05, 0xeb, 0xeb, 0x49 // add al r9 r5 r11 ASR 19
};
const byte kInstruction_add_al_r8_r11_r5_LSR_30[] = {
  0x0b, 0xeb, 0x95, 0x78 // add al r8 r11 r5 LSR 30
};
const byte kInstruction_add_al_r4_r10_r4_LSR_23[] = {
  0x0a, 0xeb, 0xd4, 0x54 // add al r4 r10 r4 LSR 23
};
const byte kInstruction_add_al_r7_r6_r2_LSR_32[] = {
  0x06, 0xeb, 0x12, 0x07 // add al r7 r6 r2 LSR 32
};
const byte kInstruction_add_al_r4_r14_r12_LSR_7[] = {
  0x0e, 0xeb, 0xdc, 0x14 // add al r4 r14 r12 LSR 7
};
const byte kInstruction_add_al_r5_r2_r9_LSR_7[] = {
  0x02, 0xeb, 0xd9, 0x15 // add al r5 r2 r9 LSR 7
};
const byte kInstruction_add_al_r2_r14_r1_ASR_6[] = {
  0x0e, 0xeb, 0xa1, 0x12 // add al r2 r14 r1 ASR 6
};
const byte kInstruction_add_al_r14_r13_r11_LSR_12[] = {
  0x0d, 0xeb, 0x1b, 0x3e // add al r14 r13 r11 LSR 12
};
const byte kInstruction_add_al_r8_r8_r6_ASR_5[] = {
  0x08, 0xeb, 0x66, 0x18 // add al r8 r8 r6 ASR 5
};
const byte kInstruction_add_al_r14_r10_r12_LSR_13[] = {
  0x0a, 0xeb, 0x5c, 0x3e // add al r14 r10 r12 LSR 13
};
const byte kInstruction_add_al_r3_r6_r7_LSR_31[] = {
  0x06, 0xeb, 0xd7, 0x73 // add al r3 r6 r7 LSR 31
};
const byte kInstruction_add_al_r8_r1_r9_ASR_2[] = {
  0x01, 0xeb, 0xa9, 0x08 // add al r8 r1 r9 ASR 2
};
const byte kInstruction_add_al_r9_r12_r12_ASR_21[] = {
  0x0c, 0xeb, 0x6c, 0x59 // add al r9 r12 r12 ASR 21
};
const byte kInstruction_add_al_r13_r4_r12_LSR_14[] = {
  0x04, 0xeb, 0x9c, 0x3d // add al r13 r4 r12 LSR 14
};
const byte kInstruction_add_al_r2_r11_r12_LSR_18[] = {
  0x0b, 0xeb, 0x9c, 0x42 // add al r2 r11 r12 LSR 18
};
const byte kInstruction_add_al_r9_r3_r0_ASR_31[] = {
  0x03, 0xeb, 0xe0, 0x79 // add al r9 r3 r0 ASR 31
};
const byte kInstruction_add_al_r13_r6_r12_LSR_6[] = {
  0x06, 0xeb, 0x9c, 0x1d // add al r13 r6 r12 LSR 6
};
const byte kInstruction_add_al_r1_r1_r7_LSR_3[] = {
  0x01, 0xeb, 0xd7, 0x01 // add al r1 r1 r7 LSR 3
};
const byte kInstruction_add_al_r0_r13_r9_ASR_1[] = {
  0x0d, 0xeb, 0x69, 0x00 // add al r0 r13 r9 ASR 1
};
const byte kInstruction_add_al_r2_r1_r3_LSR_12[] = {
  0x01, 0xeb, 0x13, 0x32 // add al r2 r1 r3 LSR 12
};
const byte kInstruction_add_al_r12_r6_r10_ASR_1[] = {
  0x06, 0xeb, 0x6a, 0x0c // add al r12 r6 r10 ASR 1
};
const byte kInstruction_add_al_r12_r4_r3_ASR_4[] = {
  0x04, 0xeb, 0x23, 0x1c // add al r12 r4 r3 ASR 4
};
const byte kInstruction_add_al_r7_r0_r5_LSR_25[] = {
  0x00, 0xeb, 0x55, 0x67 // add al r7 r0 r5 LSR 25
};
const byte kInstruction_add_al_r4_r5_r12_LSR_20[] = {
  0x05, 0xeb, 0x1c, 0x54 // add al r4 r5 r12 LSR 20
};
const byte kInstruction_add_al_r3_r5_r11_LSR_24[] = {
  0x05, 0xeb, 0x1b, 0x63 // add al r3 r5 r11 LSR 24
};
const byte kInstruction_add_al_r5_r8_r10_LSR_25[] = {
  0x08, 0xeb, 0x5a, 0x65 // add al r5 r8 r10 LSR 25
};
const byte kInstruction_add_al_r11_r9_r12_LSR_24[] = {
  0x09, 0xeb, 0x1c, 0x6b // add al r11 r9 r12 LSR 24
};
const byte kInstruction_add_al_r13_r11_r13_LSR_20[] = {
  0x0b, 0xeb, 0x1d, 0x5d // add al r13 r11 r13 LSR 20
};
const byte kInstruction_add_al_r12_r4_r3_ASR_32[] = {
  0x04, 0xeb, 0x23, 0x0c // add al r12 r4 r3 ASR 32
};
const byte kInstruction_add_al_r3_r6_r11_ASR_13[] = {
  0x06, 0xeb, 0x6b, 0x33 // add al r3 r6 r11 ASR 13
};
const byte kInstruction_add_al_r13_r9_r7_LSR_27[] = {
  0x09, 0xeb, 0xd7, 0x6d // add al r13 r9 r7 LSR 27
};
const byte kInstruction_add_al_r13_r9_r6_LSR_24[] = {
  0x09, 0xeb, 0x16, 0x6d // add al r13 r9 r6 LSR 24
};
const byte kInstruction_add_al_r6_r13_r3_ASR_1[] = {
  0x0d, 0xeb, 0x63, 0x06 // add al r6 r13 r3 ASR 1
};
const byte kInstruction_add_al_r8_r7_r14_ASR_27[] = {
  0x07, 0xeb, 0xee, 0x68 // add al r8 r7 r14 ASR 27
};
const byte kInstruction_add_al_r8_r8_r8_LSR_29[] = {
  0x08, 0xeb, 0x58, 0x78 // add al r8 r8 r8 LSR 29
};
const byte kInstruction_add_al_r1_r13_r4_ASR_26[] = {
  0x0d, 0xeb, 0xa4, 0x61 // add al r1 r13 r4 ASR 26
};
const byte kInstruction_add_al_r3_r2_r10_LSR_16[] = {
  0x02, 0xeb, 0x1a, 0x43 // add al r3 r2 r10 LSR 16
};
const byte kInstruction_add_al_r2_r11_r9_ASR_29[] = {
  0x0b, 0xeb, 0x69, 0x72 // add al r2 r11 r9 ASR 29
};
const byte kInstruction_add_al_r12_r9_r8_LSR_7[] = {
  0x09, 0xeb, 0xd8, 0x1c // add al r12 r9 r8 LSR 7
};
const byte kInstruction_add_al_r6_r2_r0_LSR_4[] = {
  0x02, 0xeb, 0x10, 0x16 // add al r6 r2 r0 LSR 4
};
const byte kInstruction_add_al_r12_r2_r11_LSR_8[] = {
  0x02, 0xeb, 0x1b, 0x2c // add al r12 r2 r11 LSR 8
};
const byte kInstruction_add_al_r0_r10_r12_LSR_5[] = {
  0x0a, 0xeb, 0x5c, 0x10 // add al r0 r10 r12 LSR 5
};
const byte kInstruction_add_al_r2_r2_r2_ASR_4[] = {
  0x02, 0xeb, 0x22, 0x12 // add al r2 r2 r2 ASR 4
};
const byte kInstruction_add_al_r4_r13_r11_LSR_15[] = {
  0x0d, 0xeb, 0xdb, 0x34 // add al r4 r13 r11 LSR 15
};
const byte kInstruction_add_al_r4_r2_r13_ASR_4[] = {
  0x02, 0xeb, 0x2d, 0x14 // add al r4 r2 r13 ASR 4
};
const byte kInstruction_add_al_r4_r4_r7_LSR_30[] = {
  0x04, 0xeb, 0x97, 0x74 // add al r4 r4 r7 LSR 30
};
const byte kInstruction_add_al_r4_r8_r10_LSR_14[] = {
  0x08, 0xeb, 0x9a, 0x34 // add al r4 r8 r10 LSR 14
};
const byte kInstruction_add_al_r14_r8_r11_ASR_16[] = {
  0x08, 0xeb, 0x2b, 0x4e // add al r14 r8 r11 ASR 16
};
const byte kInstruction_add_al_r0_r8_r1_LSR_25[] = {
  0x08, 0xeb, 0x51, 0x60 // add al r0 r8 r1 LSR 25
};
const byte kInstruction_add_al_r14_r13_r14_ASR_3[] = {
  0x0d, 0xeb, 0xee, 0x0e // add al r14 r13 r14 ASR 3
};
const byte kInstruction_add_al_r13_r8_r13_ASR_31[] = {
  0x08, 0xeb, 0xed, 0x7d // add al r13 r8 r13 ASR 31
};
const byte kInstruction_add_al_r9_r6_r1_LSR_28[] = {
  0x06, 0xeb, 0x11, 0x79 // add al r9 r6 r1 LSR 28
};
const byte kInstruction_add_al_r4_r14_r1_ASR_9[] = {
  0x0e, 0xeb, 0x61, 0x24 // add al r4 r14 r1 ASR 9
};
const byte kInstruction_add_al_r8_r0_r14_LSR_7[] = {
  0x00, 0xeb, 0xde, 0x18 // add al r8 r0 r14 LSR 7
};
const byte kInstruction_add_al_r8_r8_r12_ASR_14[] = {
  0x08, 0xeb, 0xac, 0x38 // add al r8 r8 r12 ASR 14
};
const byte kInstruction_add_al_r9_r14_r12_ASR_19[] = {
  0x0e, 0xeb, 0xec, 0x49 // add al r9 r14 r12 ASR 19
};
const byte kInstruction_add_al_r4_r14_r11_ASR_25[] = {
  0x0e, 0xeb, 0x6b, 0x64 // add al r4 r14 r11 ASR 25
};
const byte kInstruction_add_al_r1_r0_r9_ASR_13[] = {
  0x00, 0xeb, 0x69, 0x31 // add al r1 r0 r9 ASR 13
};
const byte kInstruction_add_al_r8_r13_r9_LSR_4[] = {
  0x0d, 0xeb, 0x19, 0x18 // add al r8 r13 r9 LSR 4
};
const byte kInstruction_add_al_r2_r4_r4_LSR_3[] = {
  0x04, 0xeb, 0xd4, 0x02 // add al r2 r4 r4 LSR 3
};
const byte kInstruction_add_al_r14_r13_r3_LSR_8[] = {
  0x0d, 0xeb, 0x13, 0x2e // add al r14 r13 r3 LSR 8
};
const byte kInstruction_add_al_r11_r6_r3_LSR_10[] = {
  0x06, 0xeb, 0x93, 0x2b // add al r11 r6 r3 LSR 10
};
const byte kInstruction_add_al_r13_r8_r4_ASR_31[] = {
  0x08, 0xeb, 0xe4, 0x7d // add al r13 r8 r4 ASR 31
};
const byte kInstruction_add_al_r8_r11_r0_LSR_13[] = {
  0x0b, 0xeb, 0x50, 0x38 // add al r8 r11 r0 LSR 13
};
const byte kInstruction_add_al_r10_r5_r10_ASR_19[] = {
  0x05, 0xeb, 0xea, 0x4a // add al r10 r5 r10 ASR 19
};
const byte kInstruction_add_al_r13_r4_r5_ASR_2[] = {
  0x04, 0xeb, 0xa5, 0x0d // add al r13 r4 r5 ASR 2
};
const byte kInstruction_add_al_r8_r4_r10_LSR_3[] = {
  0x04, 0xeb, 0xda, 0x08 // add al r8 r4 r10 LSR 3
};
const byte kInstruction_add_al_r13_r7_r3_LSR_6[] = {
  0x07, 0xeb, 0x93, 0x1d // add al r13 r7 r3 LSR 6
};
const byte kInstruction_add_al_r6_r1_r8_LSR_1[] = {
  0x01, 0xeb, 0x58, 0x06 // add al r6 r1 r8 LSR 1
};
const byte kInstruction_add_al_r5_r13_r9_LSR_31[] = {
  0x0d, 0xeb, 0xd9, 0x75 // add al r5 r13 r9 LSR 31
};
const byte kInstruction_add_al_r11_r8_r0_ASR_19[] = {
  0x08, 0xeb, 0xe0, 0x4b // add al r11 r8 r0 ASR 19
};
const byte kInstruction_add_al_r14_r6_r8_LSR_25[] = {
  0x06, 0xeb, 0x58, 0x6e // add al r14 r6 r8 LSR 25
};
const byte kInstruction_add_al_r10_r6_r7_ASR_28[] = {
  0x06, 0xeb, 0x27, 0x7a // add al r10 r6 r7 ASR 28
};
const byte kInstruction_add_al_r5_r2_r9_LSR_12[] = {
  0x02, 0xeb, 0x19, 0x35 // add al r5 r2 r9 LSR 12
};
const byte kInstruction_add_al_r1_r2_r6_ASR_18[] = {
  0x02, 0xeb, 0xa6, 0x41 // add al r1 r2 r6 ASR 18
};
const byte kInstruction_add_al_r10_r13_r11_ASR_14[] = {
  0x0d, 0xeb, 0xab, 0x3a // add al r10 r13 r11 ASR 14
};
const byte kInstruction_add_al_r6_r8_r8_LSR_14[] = {
  0x08, 0xeb, 0x98, 0x36 // add al r6 r8 r8 LSR 14
};
const byte kInstruction_add_al_r7_r14_r11_ASR_18[] = {
  0x0e, 0xeb, 0xab, 0x47 // add al r7 r14 r11 ASR 18
};
const byte kInstruction_add_al_r3_r11_r2_LSR_13[] = {
  0x0b, 0xeb, 0x52, 0x33 // add al r3 r11 r2 LSR 13
};
const byte kInstruction_add_al_r14_r7_r6_ASR_10[] = {
  0x07, 0xeb, 0xa6, 0x2e // add al r14 r7 r6 ASR 10
};
const byte kInstruction_add_al_r6_r5_r7_ASR_12[] = {
  0x05, 0xeb, 0x27, 0x36 // add al r6 r5 r7 ASR 12
};
const byte kInstruction_add_al_r5_r2_r9_ASR_13[] = {
  0x02, 0xeb, 0x69, 0x35 // add al r5 r2 r9 ASR 13
};
const byte kInstruction_add_al_r12_r13_r3_LSR_14[] = {
  0x0d, 0xeb, 0x93, 0x3c // add al r12 r13 r3 LSR 14
};
const byte kInstruction_add_al_r10_r4_r0_ASR_23[] = {
  0x04, 0xeb, 0xe0, 0x5a // add al r10 r4 r0 ASR 23
};
const byte kInstruction_add_al_r10_r12_r2_LSR_18[] = {
  0x0c, 0xeb, 0x92, 0x4a // add al r10 r12 r2 LSR 18
};
const byte kInstruction_add_al_r4_r10_r14_ASR_18[] = {
  0x0a, 0xeb, 0xae, 0x44 // add al r4 r10 r14 ASR 18
};
const byte kInstruction_add_al_r13_r0_r1_LSR_7[] = {
  0x00, 0xeb, 0xd1, 0x1d // add al r13 r0 r1 LSR 7
};
const byte kInstruction_add_al_r3_r3_r13_LSR_16[] = {
  0x03, 0xeb, 0x1d, 0x43 // add al r3 r3 r13 LSR 16
};
const byte kInstruction_add_al_r7_r4_r4_ASR_19[] = {
  0x04, 0xeb, 0xe4, 0x47 // add al r7 r4 r4 ASR 19
};
const byte kInstruction_add_al_r6_r7_r4_ASR_13[] = {
  0x07, 0xeb, 0x64, 0x36 // add al r6 r7 r4 ASR 13
};
const byte kInstruction_add_al_r8_r10_r11_LSR_14[] = {
  0x0a, 0xeb, 0x9b, 0x38 // add al r8 r10 r11 LSR 14
};
const byte kInstruction_add_al_r0_r0_r1_ASR_32[] = {
  0x00, 0xeb, 0x21, 0x00 // add al r0 r0 r1 ASR 32
};
const byte kInstruction_add_al_r10_r12_r0_LSR_17[] = {
  0x0c, 0xeb, 0x50, 0x4a // add al r10 r12 r0 LSR 17
};
const byte kInstruction_add_al_r2_r5_r12_ASR_8[] = {
  0x05, 0xeb, 0x2c, 0x22 // add al r2 r5 r12 ASR 8
};
const byte kInstruction_add_al_r4_r3_r11_LSR_1[] = {
  0x03, 0xeb, 0x5b, 0x04 // add al r4 r3 r11 LSR 1
};
const byte kInstruction_add_al_r12_r13_r12_LSR_22[] = {
  0x0d, 0xeb, 0x9c, 0x5c // add al r12 r13 r12 LSR 22
};
const byte kInstruction_add_al_r8_r13_r11_LSR_12[] = {
  0x0d, 0xeb, 0x1b, 0x38 // add al r8 r13 r11 LSR 12
};
const byte kInstruction_add_al_r9_r11_r3_LSR_27[] = {
  0x0b, 0xeb, 0xd3, 0x69 // add al r9 r11 r3 LSR 27
};
const byte kInstruction_add_al_r8_r9_r10_ASR_21[] = {
  0x09, 0xeb, 0x6a, 0x58 // add al r8 r9 r10 ASR 21
};
const byte kInstruction_add_al_r10_r3_r0_LSR_8[] = {
  0x03, 0xeb, 0x10, 0x2a // add al r10 r3 r0 LSR 8
};
const byte kInstruction_add_al_r9_r2_r6_LSR_32[] = {
  0x02, 0xeb, 0x16, 0x09 // add al r9 r2 r6 LSR 32
};
const byte kInstruction_add_al_r9_r0_r9_ASR_24[] = {
  0x00, 0xeb, 0x29, 0x69 // add al r9 r0 r9 ASR 24
};
const byte kInstruction_add_al_r0_r10_r7_LSR_7[] = {
  0x0a, 0xeb, 0xd7, 0x10 // add al r0 r10 r7 LSR 7
};
const byte kInstruction_add_al_r7_r11_r12_LSR_14[] = {
  0x0b, 0xeb, 0x9c, 0x37 // add al r7 r11 r12 LSR 14
};
const byte kInstruction_add_al_r12_r10_r13_ASR_29[] = {
  0x0a, 0xeb, 0x6d, 0x7c // add al r12 r10 r13 ASR 29
};
const byte kInstruction_add_al_r2_r14_r3_LSR_5[] = {
  0x0e, 0xeb, 0x53, 0x12 // add al r2 r14 r3 LSR 5
};
const byte kInstruction_add_al_r14_r3_r12_ASR_19[] = {
  0x03, 0xeb, 0xec, 0x4e // add al r14 r3 r12 ASR 19
};
const byte kInstruction_add_al_r12_r12_r11_ASR_31[] = {
  0x0c, 0xeb, 0xeb, 0x7c // add al r12 r12 r11 ASR 31
};
const byte kInstruction_add_al_r0_r3_r2_ASR_4[] = {
  0x03, 0xeb, 0x22, 0x10 // add al r0 r3 r2 ASR 4
};
const byte kInstruction_add_al_r13_r2_r11_ASR_9[] = {
  0x02, 0xeb, 0x6b, 0x2d // add al r13 r2 r11 ASR 9
};
const byte kInstruction_add_al_r12_r14_r9_LSR_13[] = {
  0x0e, 0xeb, 0x59, 0x3c // add al r12 r14 r9 LSR 13
};
const byte kInstruction_add_al_r14_r3_r3_ASR_28[] = {
  0x03, 0xeb, 0x23, 0x7e // add al r14 r3 r3 ASR 28
};
const byte kInstruction_add_al_r12_r5_r12_LSR_19[] = {
  0x05, 0xeb, 0xdc, 0x4c // add al r12 r5 r12 LSR 19
};
const byte kInstruction_add_al_r9_r13_r1_LSR_14[] = {
  0x0d, 0xeb, 0x91, 0x39 // add al r9 r13 r1 LSR 14
};
const byte kInstruction_add_al_r5_r3_r1_LSR_11[] = {
  0x03, 0xeb, 0xd1, 0x25 // add al r5 r3 r1 LSR 11
};
const byte kInstruction_add_al_r0_r14_r5_ASR_22[] = {
  0x0e, 0xeb, 0xa5, 0x50 // add al r0 r14 r5 ASR 22
};
const byte kInstruction_add_al_r8_r9_r8_ASR_12[] = {
  0x09, 0xeb, 0x28, 0x38 // add al r8 r9 r8 ASR 12
};
const byte kInstruction_add_al_r9_r0_r13_LSR_15[] = {
  0x00, 0xeb, 0xdd, 0x39 // add al r9 r0 r13 LSR 15
};
const byte kInstruction_add_al_r9_r5_r14_ASR_9[] = {
  0x05, 0xeb, 0x6e, 0x29 // add al r9 r5 r14 ASR 9
};
const byte kInstruction_add_al_r9_r13_r13_LSR_16[] = {
  0x0d, 0xeb, 0x1d, 0x49 // add al r9 r13 r13 LSR 16
};
const byte kInstruction_add_al_r7_r0_r8_ASR_17[] = {
  0x00, 0xeb, 0x68, 0x47 // add al r7 r0 r8 ASR 17
};
const byte kInstruction_add_al_r10_r13_r14_ASR_30[] = {
  0x0d, 0xeb, 0xae, 0x7a // add al r10 r13 r14 ASR 30
};
const byte kInstruction_add_al_r7_r10_r4_LSR_8[] = {
  0x0a, 0xeb, 0x14, 0x27 // add al r7 r10 r4 LSR 8
};
const byte kInstruction_add_al_r10_r5_r1_ASR_2[] = {
  0x05, 0xeb, 0xa1, 0x0a // add al r10 r5 r1 ASR 2
};
const byte kInstruction_add_al_r4_r10_r2_LSR_10[] = {
  0x0a, 0xeb, 0x92, 0x24 // add al r4 r10 r2 LSR 10
};
const byte kInstruction_add_al_r3_r5_r0_LSR_22[] = {
  0x05, 0xeb, 0x90, 0x53 // add al r3 r5 r0 LSR 22
};
const byte kInstruction_add_al_r13_r11_r12_LSR_22[] = {
  0x0b, 0xeb, 0x9c, 0x5d // add al r13 r11 r12 LSR 22
};
const byte kInstruction_add_al_r0_r8_r6_LSR_6[] = {
  0x08, 0xeb, 0x96, 0x10 // add al r0 r8 r6 LSR 6
};
const byte kInstruction_add_al_r13_r4_r1_LSR_30[] = {
  0x04, 0xeb, 0x91, 0x7d // add al r13 r4 r1 LSR 30
};
const byte kInstruction_add_al_r13_r9_r12_ASR_20[] = {
  0x09, 0xeb, 0x2c, 0x5d // add al r13 r9 r12 ASR 20
};
const byte kInstruction_add_al_r0_r5_r10_ASR_2[] = {
  0x05, 0xeb, 0xaa, 0x00 // add al r0 r5 r10 ASR 2
};
const byte kInstruction_add_al_r10_r4_r0_ASR_13[] = {
  0x04, 0xeb, 0x60, 0x3a // add al r10 r4 r0 ASR 13
};
const byte kInstruction_add_al_r12_r3_r0_LSR_16[] = {
  0x03, 0xeb, 0x10, 0x4c // add al r12 r3 r0 LSR 16
};
const byte kInstruction_add_al_r7_r11_r14_ASR_25[] = {
  0x0b, 0xeb, 0x6e, 0x67 // add al r7 r11 r14 ASR 25
};
const byte kInstruction_add_al_r8_r9_r12_ASR_31[] = {
  0x09, 0xeb, 0xec, 0x78 // add al r8 r9 r12 ASR 31
};
const byte kInstruction_add_al_r14_r11_r8_LSR_26[] = {
  0x0b, 0xeb, 0x98, 0x6e // add al r14 r11 r8 LSR 26
};
const byte kInstruction_add_al_r8_r3_r6_ASR_31[] = {
  0x03, 0xeb, 0xe6, 0x78 // add al r8 r3 r6 ASR 31
};
const byte kInstruction_add_al_r10_r4_r5_ASR_9[] = {
  0x04, 0xeb, 0x65, 0x2a // add al r10 r4 r5 ASR 9
};
const byte kInstruction_add_al_r9_r4_r6_LSR_31[] = {
  0x04, 0xeb, 0xd6, 0x79 // add al r9 r4 r6 LSR 31
};
const byte kInstruction_add_al_r12_r6_r12_LSR_32[] = {
  0x06, 0xeb, 0x1c, 0x0c // add al r12 r6 r12 LSR 32
};
const byte kInstruction_add_al_r5_r8_r9_LSR_15[] = {
  0x08, 0xeb, 0xd9, 0x35 // add al r5 r8 r9 LSR 15
};
const byte kInstruction_add_al_r1_r7_r0_LSR_4[] = {
  0x07, 0xeb, 0x10, 0x11 // add al r1 r7 r0 LSR 4
};
const byte kInstruction_add_al_r14_r5_r3_LSR_11[] = {
  0x05, 0xeb, 0xd3, 0x2e // add al r14 r5 r3 LSR 11
};
const byte kInstruction_add_al_r0_r5_r11_ASR_2[] = {
  0x05, 0xeb, 0xab, 0x00 // add al r0 r5 r11 ASR 2
};
const byte kInstruction_add_al_r11_r13_r7_ASR_4[] = {
  0x0d, 0xeb, 0x27, 0x1b // add al r11 r13 r7 ASR 4
};
const byte kInstruction_add_al_r8_r13_r12_LSR_7[] = {
  0x0d, 0xeb, 0xdc, 0x18 // add al r8 r13 r12 LSR 7
};
const byte kInstruction_add_al_r2_r11_r2_ASR_28[] = {
  0x0b, 0xeb, 0x22, 0x72 // add al r2 r11 r2 ASR 28
};
const byte kInstruction_add_al_r9_r14_r11_LSR_14[] = {
  0x0e, 0xeb, 0x9b, 0x39 // add al r9 r14 r11 LSR 14
};
const byte kInstruction_add_al_r5_r12_r4_ASR_24[] = {
  0x0c, 0xeb, 0x24, 0x65 // add al r5 r12 r4 ASR 24
};
const byte kInstruction_add_al_r9_r13_r3_LSR_19[] = {
  0x0d, 0xeb, 0xd3, 0x49 // add al r9 r13 r3 LSR 19
};
const byte kInstruction_add_al_r6_r3_r3_ASR_25[] = {
  0x03, 0xeb, 0x63, 0x66 // add al r6 r3 r3 ASR 25
};
const byte kInstruction_add_al_r13_r6_r6_LSR_16[] = {
  0x06, 0xeb, 0x16, 0x4d // add al r13 r6 r6 LSR 16
};
const byte kInstruction_add_al_r0_r9_r5_ASR_30[] = {
  0x09, 0xeb, 0xa5, 0x70 // add al r0 r9 r5 ASR 30
};
const byte kInstruction_add_al_r9_r9_r0_LSR_5[] = {
  0x09, 0xeb, 0x50, 0x19 // add al r9 r9 r0 LSR 5
};
const byte kInstruction_add_al_r0_r5_r14_LSR_12[] = {
  0x05, 0xeb, 0x1e, 0x30 // add al r0 r5 r14 LSR 12
};
const byte kInstruction_add_al_r14_r12_r7_ASR_7[] = {
  0x0c, 0xeb, 0xe7, 0x1e // add al r14 r12 r7 ASR 7
};
const byte kInstruction_add_al_r8_r13_r6_ASR_27[] = {
  0x0d, 0xeb, 0xe6, 0x68 // add al r8 r13 r6 ASR 27
};
const byte kInstruction_add_al_r12_r6_r13_LSR_24[] = {
  0x06, 0xeb, 0x1d, 0x6c // add al r12 r6 r13 LSR 24
};
const byte kInstruction_add_al_r7_r10_r6_ASR_32[] = {
  0x0a, 0xeb, 0x26, 0x07 // add al r7 r10 r6 ASR 32
};
const byte kInstruction_add_al_r6_r12_r13_ASR_8[] = {
  0x0c, 0xeb, 0x2d, 0x26 // add al r6 r12 r13 ASR 8
};
const byte kInstruction_add_al_r13_r0_r8_LSR_19[] = {
  0x00, 0xeb, 0xd8, 0x4d // add al r13 r0 r8 LSR 19
};
const byte kInstruction_add_al_r10_r9_r10_LSR_20[] = {
  0x09, 0xeb, 0x1a, 0x5a // add al r10 r9 r10 LSR 20
};
const byte kInstruction_add_al_r5_r7_r2_LSR_25[] = {
  0x07, 0xeb, 0x52, 0x65 // add al r5 r7 r2 LSR 25
};
const byte kInstruction_add_al_r2_r6_r0_LSR_15[] = {
  0x06, 0xeb, 0xd0, 0x32 // add al r2 r6 r0 LSR 15
};
const byte kInstruction_add_al_r12_r6_r8_LSR_21[] = {
  0x06, 0xeb, 0x58, 0x5c // add al r12 r6 r8 LSR 21
};
const byte kInstruction_add_al_r14_r13_r2_LSR_29[] = {
  0x0d, 0xeb, 0x52, 0x7e // add al r14 r13 r2 LSR 29
};
const byte kInstruction_add_al_r1_r13_r0_LSR_21[] = {
  0x0d, 0xeb, 0x50, 0x51 // add al r1 r13 r0 LSR 21
};
const byte kInstruction_add_al_r6_r7_r8_ASR_13[] = {
  0x07, 0xeb, 0x68, 0x36 // add al r6 r7 r8 ASR 13
};
const byte kInstruction_add_al_r13_r2_r10_ASR_8[] = {
  0x02, 0xeb, 0x2a, 0x2d // add al r13 r2 r10 ASR 8
};
const byte kInstruction_add_al_r5_r13_r7_LSR_2[] = {
  0x0d, 0xeb, 0x97, 0x05 // add al r5 r13 r7 LSR 2
};
const byte kInstruction_add_al_r0_r3_r2_LSR_17[] = {
  0x03, 0xeb, 0x52, 0x40 // add al r0 r3 r2 LSR 17
};
const byte kInstruction_add_al_r1_r8_r9_LSR_3[] = {
  0x08, 0xeb, 0xd9, 0x01 // add al r1 r8 r9 LSR 3
};
const byte kInstruction_add_al_r11_r3_r1_LSR_29[] = {
  0x03, 0xeb, 0x51, 0x7b // add al r11 r3 r1 LSR 29
};
const byte kInstruction_add_al_r2_r2_r11_LSR_17[] = {
  0x02, 0xeb, 0x5b, 0x42 // add al r2 r2 r11 LSR 17
};
const byte kInstruction_add_al_r7_r14_r11_LSR_22[] = {
  0x0e, 0xeb, 0x9b, 0x57 // add al r7 r14 r11 LSR 22
};
const byte kInstruction_add_al_r8_r7_r14_LSR_17[] = {
  0x07, 0xeb, 0x5e, 0x48 // add al r8 r7 r14 LSR 17
};
const byte kInstruction_add_al_r14_r2_r7_ASR_32[] = {
  0x02, 0xeb, 0x27, 0x0e // add al r14 r2 r7 ASR 32
};
const byte kInstruction_add_al_r0_r6_r9_ASR_13[] = {
  0x06, 0xeb, 0x69, 0x30 // add al r0 r6 r9 ASR 13
};
const byte kInstruction_add_al_r3_r5_r4_ASR_24[] = {
  0x05, 0xeb, 0x24, 0x63 // add al r3 r5 r4 ASR 24
};
const byte kInstruction_add_al_r10_r10_r6_ASR_1[] = {
  0x0a, 0xeb, 0x66, 0x0a // add al r10 r10 r6 ASR 1
};
const byte kInstruction_add_al_r8_r9_r4_ASR_5[] = {
  0x09, 0xeb, 0x64, 0x18 // add al r8 r9 r4 ASR 5
};
const byte kInstruction_add_al_r3_r0_r6_LSR_25[] = {
  0x00, 0xeb, 0x56, 0x63 // add al r3 r0 r6 LSR 25
};
const byte kInstruction_add_al_r12_r7_r12_ASR_11[] = {
  0x07, 0xeb, 0xec, 0x2c // add al r12 r7 r12 ASR 11
};
const byte kInstruction_add_al_r10_r9_r7_ASR_2[] = {
  0x09, 0xeb, 0xa7, 0x0a // add al r10 r9 r7 ASR 2
};
const byte kInstruction_add_al_r13_r13_r5_ASR_2[] = {
  0x0d, 0xeb, 0xa5, 0x0d // add al r13 r13 r5 ASR 2
};
const byte kInstruction_add_al_r11_r3_r2_ASR_5[] = {
  0x03, 0xeb, 0x62, 0x1b // add al r11 r3 r2 ASR 5
};
const byte kInstruction_add_al_r0_r8_r8_ASR_10[] = {
  0x08, 0xeb, 0xa8, 0x20 // add al r0 r8 r8 ASR 10
};
const byte kInstruction_add_al_r10_r12_r12_ASR_19[] = {
  0x0c, 0xeb, 0xec, 0x4a // add al r10 r12 r12 ASR 19
};
const byte kInstruction_add_al_r2_r6_r0_LSR_10[] = {
  0x06, 0xeb, 0x90, 0x22 // add al r2 r6 r0 LSR 10
};
const byte kInstruction_add_al_r11_r8_r8_ASR_15[] = {
  0x08, 0xeb, 0xe8, 0x3b // add al r11 r8 r8 ASR 15
};
const byte kInstruction_add_al_r14_r14_r1_LSR_14[] = {
  0x0e, 0xeb, 0x91, 0x3e // add al r14 r14 r1 LSR 14
};
const byte kInstruction_add_al_r9_r8_r12_ASR_21[] = {
  0x08, 0xeb, 0x6c, 0x59 // add al r9 r8 r12 ASR 21
};
const byte kInstruction_add_al_r14_r14_r12_ASR_9[] = {
  0x0e, 0xeb, 0x6c, 0x2e // add al r14 r14 r12 ASR 9
};
const byte kInstruction_add_al_r0_r0_r3_ASR_22[] = {
  0x00, 0xeb, 0xa3, 0x50 // add al r0 r0 r3 ASR 22
};
const byte kInstruction_add_al_r9_r7_r13_LSR_16[] = {
  0x07, 0xeb, 0x1d, 0x49 // add al r9 r7 r13 LSR 16
};
const byte kInstruction_add_al_r8_r1_r5_LSR_28[] = {
  0x01, 0xeb, 0x15, 0x78 // add al r8 r1 r5 LSR 28
};
const byte kInstruction_add_al_r0_r2_r11_LSR_21[] = {
  0x02, 0xeb, 0x5b, 0x50 // add al r0 r2 r11 LSR 21
};
const byte kInstruction_add_al_r5_r12_r8_LSR_25[] = {
  0x0c, 0xeb, 0x58, 0x65 // add al r5 r12 r8 LSR 25
};
const byte kInstruction_add_al_r9_r5_r6_ASR_5[] = {
  0x05, 0xeb, 0x66, 0x19 // add al r9 r5 r6 ASR 5
};
const byte kInstruction_add_al_r0_r0_r7_ASR_13[] = {
  0x00, 0xeb, 0x67, 0x30 // add al r0 r0 r7 ASR 13
};
const byte kInstruction_add_al_r2_r10_r7_ASR_10[] = {
  0x0a, 0xeb, 0xa7, 0x22 // add al r2 r10 r7 ASR 10
};
const byte kInstruction_add_al_r13_r8_r14_ASR_32[] = {
  0x08, 0xeb, 0x2e, 0x0d // add al r13 r8 r14 ASR 32
};
const byte kInstruction_add_al_r3_r2_r9_ASR_30[] = {
  0x02, 0xeb, 0xa9, 0x73 // add al r3 r2 r9 ASR 30
};
const byte kInstruction_add_al_r11_r0_r14_ASR_6[] = {
  0x00, 0xeb, 0xae, 0x1b // add al r11 r0 r14 ASR 6
};
const byte kInstruction_add_al_r13_r10_r2_ASR_18[] = {
  0x0a, 0xeb, 0xa2, 0x4d // add al r13 r10 r2 ASR 18
};
const byte kInstruction_add_al_r8_r13_r1_ASR_18[] = {
  0x0d, 0xeb, 0xa1, 0x48 // add al r8 r13 r1 ASR 18
};
const byte kInstruction_add_al_r10_r4_r3_LSR_19[] = {
  0x04, 0xeb, 0xd3, 0x4a // add al r10 r4 r3 LSR 19
};
const byte kInstruction_add_al_r2_r2_r9_ASR_15[] = {
  0x02, 0xeb, 0xe9, 0x32 // add al r2 r2 r9 ASR 15
};
const byte kInstruction_add_al_r6_r4_r8_LSR_28[] = {
  0x04, 0xeb, 0x18, 0x76 // add al r6 r4 r8 LSR 28
};
const byte kInstruction_add_al_r14_r9_r6_LSR_27[] = {
  0x09, 0xeb, 0xd6, 0x6e // add al r14 r9 r6 LSR 27
};
const byte kInstruction_add_al_r3_r14_r8_LSR_18[] = {
  0x0e, 0xeb, 0x98, 0x43 // add al r3 r14 r8 LSR 18
};
const byte kInstruction_add_al_r4_r1_r14_LSR_2[] = {
  0x01, 0xeb, 0x9e, 0x04 // add al r4 r1 r14 LSR 2
};
const byte kInstruction_add_al_r13_r9_r6_ASR_16[] = {
  0x09, 0xeb, 0x26, 0x4d // add al r13 r9 r6 ASR 16
};
const byte kInstruction_add_al_r4_r1_r9_ASR_29[] = {
  0x01, 0xeb, 0x69, 0x74 // add al r4 r1 r9 ASR 29
};
const byte kInstruction_add_al_r4_r3_r2_LSR_23[] = {
  0x03, 0xeb, 0xd2, 0x54 // add al r4 r3 r2 LSR 23
};
const byte kInstruction_add_al_r11_r8_r0_LSR_19[] = {
  0x08, 0xeb, 0xd0, 0x4b // add al r11 r8 r0 LSR 19
};
const byte kInstruction_add_al_r6_r10_r4_ASR_29[] = {
  0x0a, 0xeb, 0x64, 0x76 // add al r6 r10 r4 ASR 29
};
const byte kInstruction_add_al_r8_r2_r5_ASR_25[] = {
  0x02, 0xeb, 0x65, 0x68 // add al r8 r2 r5 ASR 25
};
const byte kInstruction_add_al_r3_r10_r14_LSR_25[] = {
  0x0a, 0xeb, 0x5e, 0x63 // add al r3 r10 r14 LSR 25
};
const byte kInstruction_add_al_r4_r9_r0_LSR_32[] = {
  0x09, 0xeb, 0x10, 0x04 // add al r4 r9 r0 LSR 32
};
const byte kInstruction_add_al_r14_r10_r1_ASR_8[] = {
  0x0a, 0xeb, 0x21, 0x2e // add al r14 r10 r1 ASR 8
};
const byte kInstruction_add_al_r10_r10_r1_LSR_4[] = {
  0x0a, 0xeb, 0x11, 0x1a // add al r10 r10 r1 LSR 4
};
const byte kInstruction_add_al_r10_r2_r9_ASR_23[] = {
  0x02, 0xeb, 0xe9, 0x5a // add al r10 r2 r9 ASR 23
};
const byte kInstruction_add_al_r12_r2_r7_LSR_30[] = {
  0x02, 0xeb, 0x97, 0x7c // add al r12 r2 r7 LSR 30
};
const byte kInstruction_add_al_r13_r4_r9_ASR_20[] = {
  0x04, 0xeb, 0x29, 0x5d // add al r13 r4 r9 ASR 20
};
const byte kInstruction_add_al_r12_r13_r2_LSR_29[] = {
  0x0d, 0xeb, 0x52, 0x7c // add al r12 r13 r2 LSR 29
};
const byte kInstruction_add_al_r14_r8_r13_ASR_12[] = {
  0x08, 0xeb, 0x2d, 0x3e // add al r14 r8 r13 ASR 12
};
const byte kInstruction_add_al_r11_r14_r11_ASR_18[] = {
  0x0e, 0xeb, 0xab, 0x4b // add al r11 r14 r11 ASR 18
};
const byte kInstruction_add_al_r11_r10_r1_LSR_3[] = {
  0x0a, 0xeb, 0xd1, 0x0b // add al r11 r10 r1 LSR 3
};
const byte kInstruction_add_al_r6_r2_r0_LSR_27[] = {
  0x02, 0xeb, 0xd0, 0x66 // add al r6 r2 r0 LSR 27
};
const byte kInstruction_add_al_r13_r6_r12_ASR_6[] = {
  0x06, 0xeb, 0xac, 0x1d // add al r13 r6 r12 ASR 6
};
const byte kInstruction_add_al_r9_r2_r3_ASR_21[] = {
  0x02, 0xeb, 0x63, 0x59 // add al r9 r2 r3 ASR 21
};
const byte kInstruction_add_al_r2_r9_r4_LSR_16[] = {
  0x09, 0xeb, 0x14, 0x42 // add al r2 r9 r4 LSR 16
};
const byte kInstruction_add_al_r10_r13_r10_ASR_23[] = {
  0x0d, 0xeb, 0xea, 0x5a // add al r10 r13 r10 ASR 23
};
const byte kInstruction_add_al_r8_r13_r10_LSR_20[] = {
  0x0d, 0xeb, 0x1a, 0x58 // add al r8 r13 r10 LSR 20
};
const byte kInstruction_add_al_r0_r7_r7_ASR_17[] = {
  0x07, 0xeb, 0x67, 0x40 // add al r0 r7 r7 ASR 17
};
const byte kInstruction_add_al_r2_r5_r9_ASR_24[] = {
  0x05, 0xeb, 0x29, 0x62 // add al r2 r5 r9 ASR 24
};
const byte kInstruction_add_al_r1_r9_r7_ASR_16[] = {
  0x09, 0xeb, 0x27, 0x41 // add al r1 r9 r7 ASR 16
};
const byte kInstruction_add_al_r4_r1_r7_LSR_26[] = {
  0x01, 0xeb, 0x97, 0x64 // add al r4 r1 r7 LSR 26
};
const byte kInstruction_add_al_r6_r4_r10_LSR_26[] = {
  0x04, 0xeb, 0x9a, 0x66 // add al r6 r4 r10 LSR 26
};
const byte kInstruction_add_al_r9_r5_r7_ASR_1[] = {
  0x05, 0xeb, 0x67, 0x09 // add al r9 r5 r7 ASR 1
};
const byte kInstruction_add_al_r5_r3_r5_LSR_8[] = {
  0x03, 0xeb, 0x15, 0x25 // add al r5 r3 r5 LSR 8
};
const byte kInstruction_add_al_r7_r6_r8_LSR_28[] = {
  0x06, 0xeb, 0x18, 0x77 // add al r7 r6 r8 LSR 28
};
const byte kInstruction_add_al_r3_r5_r12_ASR_23[] = {
  0x05, 0xeb, 0xec, 0x53 // add al r3 r5 r12 ASR 23
};
const byte kInstruction_add_al_r3_r14_r9_LSR_28[] = {
  0x0e, 0xeb, 0x19, 0x73 // add al r3 r14 r9 LSR 28
};
const byte kInstruction_add_al_r14_r5_r3_LSR_21[] = {
  0x05, 0xeb, 0x53, 0x5e // add al r14 r5 r3 LSR 21
};
const byte kInstruction_add_al_r11_r0_r13_LSR_23[] = {
  0x00, 0xeb, 0xdd, 0x5b // add al r11 r0 r13 LSR 23
};
const byte kInstruction_add_al_r13_r13_r7_LSR_15[] = {
  0x0d, 0xeb, 0xd7, 0x3d // add al r13 r13 r7 LSR 15
};
const byte kInstruction_add_al_r6_r10_r8_LSR_24[] = {
  0x0a, 0xeb, 0x18, 0x66 // add al r6 r10 r8 LSR 24
};
const byte kInstruction_add_al_r8_r11_r11_ASR_28[] = {
  0x0b, 0xeb, 0x2b, 0x78 // add al r8 r11 r11 ASR 28
};
const byte kInstruction_add_al_r9_r1_r1_LSR_26[] = {
  0x01, 0xeb, 0x91, 0x69 // add al r9 r1 r1 LSR 26
};
const byte kInstruction_add_al_r2_r4_r14_LSR_2[] = {
  0x04, 0xeb, 0x9e, 0x02 // add al r2 r4 r14 LSR 2
};
const byte kInstruction_add_al_r4_r7_r2_ASR_19[] = {
  0x07, 0xeb, 0xe2, 0x44 // add al r4 r7 r2 ASR 19
};
const byte kInstruction_add_al_r9_r1_r7_ASR_23[] = {
  0x01, 0xeb, 0xe7, 0x59 // add al r9 r1 r7 ASR 23
};
const byte kInstruction_add_al_r4_r7_r11_ASR_7[] = {
  0x07, 0xeb, 0xeb, 0x14 // add al r4 r7 r11 ASR 7
};
const byte kInstruction_add_al_r7_r9_r5_ASR_32[] = {
  0x09, 0xeb, 0x25, 0x07 // add al r7 r9 r5 ASR 32
};
const byte kInstruction_add_al_r14_r6_r6_ASR_11[] = {
  0x06, 0xeb, 0xe6, 0x2e // add al r14 r6 r6 ASR 11
};
const byte kInstruction_add_al_r14_r5_r14_ASR_32[] = {
  0x05, 0xeb, 0x2e, 0x0e // add al r14 r5 r14 ASR 32
};
const byte kInstruction_add_al_r9_r2_r13_LSR_15[] = {
  0x02, 0xeb, 0xdd, 0x39 // add al r9 r2 r13 LSR 15
};
const byte kInstruction_add_al_r13_r8_r3_LSR_15[] = {
  0x08, 0xeb, 0xd3, 0x3d // add al r13 r8 r3 LSR 15
};
const byte kInstruction_add_al_r14_r0_r2_ASR_10[] = {
  0x00, 0xeb, 0xa2, 0x2e // add al r14 r0 r2 ASR 10
};
const byte kInstruction_add_al_r9_r6_r5_LSR_3[] = {
  0x06, 0xeb, 0xd5, 0x09 // add al r9 r6 r5 LSR 3
};
const byte kInstruction_add_al_r11_r10_r12_LSR_13[] = {
  0x0a, 0xeb, 0x5c, 0x3b // add al r11 r10 r12 LSR 13
};
const byte kInstruction_add_al_r7_r11_r9_LSR_11[] = {
  0x0b, 0xeb, 0xd9, 0x27 // add al r7 r11 r9 LSR 11
};
const byte kInstruction_add_al_r3_r9_r9_ASR_10[] = {
  0x09, 0xeb, 0xa9, 0x23 // add al r3 r9 r9 ASR 10
};
const byte kInstruction_add_al_r12_r14_r3_LSR_25[] = {
  0x0e, 0xeb, 0x53, 0x6c // add al r12 r14 r3 LSR 25
};
const byte kInstruction_add_al_r13_r1_r11_ASR_7[] = {
  0x01, 0xeb, 0xeb, 0x1d // add al r13 r1 r11 ASR 7
};
const byte kInstruction_add_al_r12_r9_r5_ASR_2[] = {
  0x09, 0xeb, 0xa5, 0x0c // add al r12 r9 r5 ASR 2
};
const byte kInstruction_add_al_r6_r13_r7_ASR_12[] = {
  0x0d, 0xeb, 0x27, 0x36 // add al r6 r13 r7 ASR 12
};
const byte kInstruction_add_al_r5_r1_r5_LSR_16[] = {
  0x01, 0xeb, 0x15, 0x45 // add al r5 r1 r5 LSR 16
};
const byte kInstruction_add_al_r0_r11_r13_LSR_22[] = {
  0x0b, 0xeb, 0x9d, 0x50 // add al r0 r11 r13 LSR 22
};
const byte kInstruction_add_al_r7_r8_r1_ASR_25[] = {
  0x08, 0xeb, 0x61, 0x67 // add al r7 r8 r1 ASR 25
};
const byte kInstruction_add_al_r2_r13_r9_LSR_11[] = {
  0x0d, 0xeb, 0xd9, 0x22 // add al r2 r13 r9 LSR 11
};
const byte kInstruction_add_al_r4_r9_r11_ASR_17[] = {
  0x09, 0xeb, 0x6b, 0x44 // add al r4 r9 r11 ASR 17
};
const byte kInstruction_add_al_r6_r0_r4_ASR_13[] = {
  0x00, 0xeb, 0x64, 0x36 // add al r6 r0 r4 ASR 13
};
const byte kInstruction_add_al_r9_r0_r14_LSR_23[] = {
  0x00, 0xeb, 0xde, 0x59 // add al r9 r0 r14 LSR 23
};
const byte kInstruction_add_al_r14_r11_r5_ASR_17[] = {
  0x0b, 0xeb, 0x65, 0x4e // add al r14 r11 r5 ASR 17
};
const byte kInstruction_add_al_r6_r14_r13_ASR_4[] = {
  0x0e, 0xeb, 0x2d, 0x16 // add al r6 r14 r13 ASR 4
};
const byte kInstruction_add_al_r14_r12_r7_ASR_31[] = {
  0x0c, 0xeb, 0xe7, 0x7e // add al r14 r12 r7 ASR 31
};
const byte kInstruction_add_al_r11_r10_r12_ASR_1[] = {
  0x0a, 0xeb, 0x6c, 0x0b // add al r11 r10 r12 ASR 1
};
const byte kInstruction_add_al_r14_r11_r12_ASR_25[] = {
  0x0b, 0xeb, 0x6c, 0x6e // add al r14 r11 r12 ASR 25
};
const byte kInstruction_add_al_r2_r13_r1_ASR_1[] = {
  0x0d, 0xeb, 0x61, 0x02 // add al r2 r13 r1 ASR 1
};
const byte kInstruction_add_al_r9_r2_r3_LSR_29[] = {
  0x02, 0xeb, 0x53, 0x79 // add al r9 r2 r3 LSR 29
};
const byte kInstruction_add_al_r1_r7_r6_ASR_20[] = {
  0x07, 0xeb, 0x26, 0x51 // add al r1 r7 r6 ASR 20
};
const byte kInstruction_add_al_r9_r13_r3_LSR_2[] = {
  0x0d, 0xeb, 0x93, 0x09 // add al r9 r13 r3 LSR 2
};
const byte kInstruction_add_al_r8_r12_r5_ASR_24[] = {
  0x0c, 0xeb, 0x25, 0x68 // add al r8 r12 r5 ASR 24
};
const byte kInstruction_add_al_r12_r5_r14_LSR_1[] = {
  0x05, 0xeb, 0x5e, 0x0c // add al r12 r5 r14 LSR 1
};
const byte kInstruction_add_al_r13_r4_r9_ASR_30[] = {
  0x04, 0xeb, 0xa9, 0x7d // add al r13 r4 r9 ASR 30
};
const byte kInstruction_add_al_r12_r2_r11_ASR_28[] = {
  0x02, 0xeb, 0x2b, 0x7c // add al r12 r2 r11 ASR 28
};
const byte kInstruction_add_al_r8_r2_r11_LSR_26[] = {
  0x02, 0xeb, 0x9b, 0x68 // add al r8 r2 r11 LSR 26
};
const byte kInstruction_add_al_r0_r0_r2_ASR_21[] = {
  0x00, 0xeb, 0x62, 0x50 // add al r0 r0 r2 ASR 21
};
const byte kInstruction_add_al_r7_r10_r14_LSR_22[] = {
  0x0a, 0xeb, 0x9e, 0x57 // add al r7 r10 r14 LSR 22
};
const byte kInstruction_add_al_r3_r1_r4_ASR_18[] = {
  0x01, 0xeb, 0xa4, 0x43 // add al r3 r1 r4 ASR 18
};
const byte kInstruction_add_al_r8_r14_r3_ASR_32[] = {
  0x0e, 0xeb, 0x23, 0x08 // add al r8 r14 r3 ASR 32
};
const byte kInstruction_add_al_r4_r9_r8_ASR_4[] = {
  0x09, 0xeb, 0x28, 0x14 // add al r4 r9 r8 ASR 4
};
const byte kInstruction_add_al_r7_r2_r4_ASR_14[] = {
  0x02, 0xeb, 0xa4, 0x37 // add al r7 r2 r4 ASR 14
};
const byte kInstruction_add_al_r12_r1_r9_ASR_9[] = {
  0x01, 0xeb, 0x69, 0x2c // add al r12 r1 r9 ASR 9
};
const byte kInstruction_add_al_r3_r5_r0_ASR_11[] = {
  0x05, 0xeb, 0xe0, 0x23 // add al r3 r5 r0 ASR 11
};
const byte kInstruction_add_al_r14_r9_r0_LSR_10[] = {
  0x09, 0xeb, 0x90, 0x2e // add al r14 r9 r0 LSR 10
};
const byte kInstruction_add_al_r14_r13_r6_ASR_27[] = {
  0x0d, 0xeb, 0xe6, 0x6e // add al r14 r13 r6 ASR 27
};
const byte kInstruction_add_al_r13_r8_r1_LSR_27[] = {
  0x08, 0xeb, 0xd1, 0x6d // add al r13 r8 r1 LSR 27
};
const byte kInstruction_add_al_r7_r0_r7_LSR_31[] = {
  0x00, 0xeb, 0xd7, 0x77 // add al r7 r0 r7 LSR 31
};
const byte kInstruction_add_al_r5_r8_r7_ASR_27[] = {
  0x08, 0xeb, 0xe7, 0x65 // add al r5 r8 r7 ASR 27
};
const byte kInstruction_add_al_r12_r3_r10_ASR_24[] = {
  0x03, 0xeb, 0x2a, 0x6c // add al r12 r3 r10 ASR 24
};
const byte kInstruction_add_al_r14_r14_r5_LSR_20[] = {
  0x0e, 0xeb, 0x15, 0x5e // add al r14 r14 r5 LSR 20
};
const byte kInstruction_add_al_r0_r12_r7_LSR_32[] = {
  0x0c, 0xeb, 0x17, 0x00 // add al r0 r12 r7 LSR 32
};
const byte kInstruction_add_al_r2_r3_r6_ASR_17[] = {
  0x03, 0xeb, 0x66, 0x42 // add al r2 r3 r6 ASR 17
};
const byte kInstruction_add_al_r11_r8_r13_ASR_27[] = {
  0x08, 0xeb, 0xed, 0x6b // add al r11 r8 r13 ASR 27
};
const byte kInstruction_add_al_r13_r12_r4_LSR_24[] = {
  0x0c, 0xeb, 0x14, 0x6d // add al r13 r12 r4 LSR 24
};
const byte kInstruction_add_al_r3_r3_r0_ASR_26[] = {
  0x03, 0xeb, 0xa0, 0x63 // add al r3 r3 r0 ASR 26
};
const byte kInstruction_add_al_r10_r0_r5_ASR_26[] = {
  0x00, 0xeb, 0xa5, 0x6a // add al r10 r0 r5 ASR 26
};
const byte kInstruction_add_al_r5_r9_r7_LSR_6[] = {
  0x09, 0xeb, 0x97, 0x15 // add al r5 r9 r7 LSR 6
};
const byte kInstruction_add_al_r12_r4_r9_ASR_8[] = {
  0x04, 0xeb, 0x29, 0x2c // add al r12 r4 r9 ASR 8
};
const byte kInstruction_add_al_r4_r0_r13_LSR_16[] = {
  0x00, 0xeb, 0x1d, 0x44 // add al r4 r0 r13 LSR 16
};
const byte kInstruction_add_al_r11_r2_r2_LSR_6[] = {
  0x02, 0xeb, 0x92, 0x1b // add al r11 r2 r2 LSR 6
};
const byte kInstruction_add_al_r12_r4_r3_ASR_11[] = {
  0x04, 0xeb, 0xe3, 0x2c // add al r12 r4 r3 ASR 11
};
const byte kInstruction_add_al_r0_r10_r12_ASR_22[] = {
  0x0a, 0xeb, 0xac, 0x50 // add al r0 r10 r12 ASR 22
};
const byte kInstruction_add_al_r12_r2_r12_LSR_16[] = {
  0x02, 0xeb, 0x1c, 0x4c // add al r12 r2 r12 LSR 16
};
const byte kInstruction_add_al_r2_r2_r8_ASR_14[] = {
  0x02, 0xeb, 0xa8, 0x32 // add al r2 r2 r8 ASR 14
};
const byte kInstruction_add_al_r9_r1_r3_LSR_2[] = {
  0x01, 0xeb, 0x93, 0x09 // add al r9 r1 r3 LSR 2
};
const byte kInstruction_add_al_r7_r0_r6_ASR_15[] = {
  0x00, 0xeb, 0xe6, 0x37 // add al r7 r0 r6 ASR 15
};
const byte kInstruction_add_al_r11_r2_r12_LSR_17[] = {
  0x02, 0xeb, 0x5c, 0x4b // add al r11 r2 r12 LSR 17
};
const byte kInstruction_add_al_r3_r7_r7_ASR_19[] = {
  0x07, 0xeb, 0xe7, 0x43 // add al r3 r7 r7 ASR 19
};
const byte kInstruction_add_al_r9_r13_r1_LSR_29[] = {
  0x0d, 0xeb, 0x51, 0x79 // add al r9 r13 r1 LSR 29
};
const byte kInstruction_add_al_r1_r0_r2_LSR_2[] = {
  0x00, 0xeb, 0x92, 0x01 // add al r1 r0 r2 LSR 2
};
const byte kInstruction_add_al_r14_r10_r2_ASR_12[] = {
  0x0a, 0xeb, 0x22, 0x3e // add al r14 r10 r2 ASR 12
};
const byte kInstruction_add_al_r7_r14_r11_ASR_27[] = {
  0x0e, 0xeb, 0xeb, 0x67 // add al r7 r14 r11 ASR 27
};
const byte kInstruction_add_al_r9_r8_r13_ASR_17[] = {
  0x08, 0xeb, 0x6d, 0x49 // add al r9 r8 r13 ASR 17
};
const byte kInstruction_add_al_r6_r14_r8_LSR_11[] = {
  0x0e, 0xeb, 0xd8, 0x26 // add al r6 r14 r8 LSR 11
};
const byte kInstruction_add_al_r5_r3_r9_ASR_31[] = {
  0x03, 0xeb, 0xe9, 0x75 // add al r5 r3 r9 ASR 31
};
const byte kInstruction_add_al_r5_r4_r1_ASR_29[] = {
  0x04, 0xeb, 0x61, 0x75 // add al r5 r4 r1 ASR 29
};
const byte kInstruction_add_al_r6_r5_r10_ASR_25[] = {
  0x05, 0xeb, 0x6a, 0x66 // add al r6 r5 r10 ASR 25
};
const byte kInstruction_add_al_r1_r8_r14_ASR_32[] = {
  0x08, 0xeb, 0x2e, 0x01 // add al r1 r8 r14 ASR 32
};
const byte kInstruction_add_al_r0_r3_r5_ASR_4[] = {
  0x03, 0xeb, 0x25, 0x10 // add al r0 r3 r5 ASR 4
};
const byte kInstruction_add_al_r8_r6_r1_ASR_5[] = {
  0x06, 0xeb, 0x61, 0x18 // add al r8 r6 r1 ASR 5
};
const byte kInstruction_add_al_r14_r9_r14_ASR_25[] = {
  0x09, 0xeb, 0x6e, 0x6e // add al r14 r9 r14 ASR 25
};
const byte kInstruction_add_al_r2_r10_r0_ASR_18[] = {
  0x0a, 0xeb, 0xa0, 0x42 // add al r2 r10 r0 ASR 18
};
const byte kInstruction_add_al_r12_r14_r0_LSR_23[] = {
  0x0e, 0xeb, 0xd0, 0x5c // add al r12 r14 r0 LSR 23
};
const byte kInstruction_add_al_r5_r13_r14_LSR_25[] = {
  0x0d, 0xeb, 0x5e, 0x65 // add al r5 r13 r14 LSR 25
};
const byte kInstruction_add_al_r13_r11_r10_ASR_18[] = {
  0x0b, 0xeb, 0xaa, 0x4d // add al r13 r11 r10 ASR 18
};
const byte kInstruction_add_al_r13_r9_r4_LSR_22[] = {
  0x09, 0xeb, 0x94, 0x5d // add al r13 r9 r4 LSR 22
};
const byte kInstruction_add_al_r10_r12_r5_LSR_12[] = {
  0x0c, 0xeb, 0x15, 0x3a // add al r10 r12 r5 LSR 12
};
const byte kInstruction_add_al_r0_r1_r2_ASR_28[] = {
  0x01, 0xeb, 0x22, 0x70 // add al r0 r1 r2 ASR 28
};
const byte kInstruction_add_al_r13_r5_r5_LSR_4[] = {
  0x05, 0xeb, 0x15, 0x1d // add al r13 r5 r5 LSR 4
};
const byte kInstruction_add_al_r1_r3_r10_LSR_18[] = {
  0x03, 0xeb, 0x9a, 0x41 // add al r1 r3 r10 LSR 18
};
const byte kInstruction_add_al_r2_r6_r4_LSR_4[] = {
  0x06, 0xeb, 0x14, 0x12 // add al r2 r6 r4 LSR 4
};
const byte kInstruction_add_al_r0_r3_r10_LSR_4[] = {
  0x03, 0xeb, 0x1a, 0x10 // add al r0 r3 r10 LSR 4
};
const byte kInstruction_add_al_r14_r2_r8_LSR_30[] = {
  0x02, 0xeb, 0x98, 0x7e // add al r14 r2 r8 LSR 30
};
const byte kInstruction_add_al_r10_r12_r10_ASR_18[] = {
  0x0c, 0xeb, 0xaa, 0x4a // add al r10 r12 r10 ASR 18
};
const byte kInstruction_add_al_r13_r4_r2_LSR_31[] = {
  0x04, 0xeb, 0xd2, 0x7d // add al r13 r4 r2 LSR 31
};
const byte kInstruction_add_al_r10_r11_r14_LSR_5[] = {
  0x0b, 0xeb, 0x5e, 0x1a // add al r10 r11 r14 LSR 5
};
const byte kInstruction_add_al_r3_r1_r6_ASR_8[] = {
  0x01, 0xeb, 0x26, 0x23 // add al r3 r1 r6 ASR 8
};
const byte kInstruction_add_al_r7_r14_r2_ASR_10[] = {
  0x0e, 0xeb, 0xa2, 0x27 // add al r7 r14 r2 ASR 10
};
const byte kInstruction_add_al_r8_r10_r8_ASR_8[] = {
  0x0a, 0xeb, 0x28, 0x28 // add al r8 r10 r8 ASR 8
};
const byte kInstruction_add_al_r7_r10_r4_ASR_21[] = {
  0x0a, 0xeb, 0x64, 0x57 // add al r7 r10 r4 ASR 21
};
const byte kInstruction_add_al_r6_r3_r3_ASR_6[] = {
  0x03, 0xeb, 0xa3, 0x16 // add al r6 r3 r3 ASR 6
};
const byte kInstruction_add_al_r1_r8_r6_ASR_20[] = {
  0x08, 0xeb, 0x26, 0x51 // add al r1 r8 r6 ASR 20
};
const byte kInstruction_add_al_r14_r6_r0_LSR_12[] = {
  0x06, 0xeb, 0x10, 0x3e // add al r14 r6 r0 LSR 12
};
const byte kInstruction_add_al_r8_r1_r14_LSR_19[] = {
  0x01, 0xeb, 0xde, 0x48 // add al r8 r1 r14 LSR 19
};
const byte kInstruction_add_al_r6_r7_r8_LSR_22[] = {
  0x07, 0xeb, 0x98, 0x56 // add al r6 r7 r8 LSR 22
};
const byte kInstruction_add_al_r9_r0_r11_LSR_8[] = {
  0x00, 0xeb, 0x1b, 0x29 // add al r9 r0 r11 LSR 8
};
const byte kInstruction_add_al_r10_r3_r2_LSR_6[] = {
  0x03, 0xeb, 0x92, 0x1a // add al r10 r3 r2 LSR 6
};
const byte kInstruction_add_al_r2_r14_r0_ASR_12[] = {
  0x0e, 0xeb, 0x20, 0x32 // add al r2 r14 r0 ASR 12
};
const byte kInstruction_add_al_r6_r3_r5_LSR_22[] = {
  0x03, 0xeb, 0x95, 0x56 // add al r6 r3 r5 LSR 22
};
const byte kInstruction_add_al_r2_r13_r9_LSR_12[] = {
  0x0d, 0xeb, 0x19, 0x32 // add al r2 r13 r9 LSR 12
};
const byte kInstruction_add_al_r14_r5_r2_LSR_5[] = {
  0x05, 0xeb, 0x52, 0x1e // add al r14 r5 r2 LSR 5
};
const byte kInstruction_add_al_r4_r10_r12_LSR_32[] = {
  0x0a, 0xeb, 0x1c, 0x04 // add al r4 r10 r12 LSR 32
};
const byte kInstruction_add_al_r1_r12_r2_ASR_1[] = {
  0x0c, 0xeb, 0x62, 0x01 // add al r1 r12 r2 ASR 1
};
const byte kInstruction_add_al_r7_r11_r3_ASR_27[] = {
  0x0b, 0xeb, 0xe3, 0x67 // add al r7 r11 r3 ASR 27
};
const byte kInstruction_add_al_r3_r2_r2_ASR_29[] = {
  0x02, 0xeb, 0x62, 0x73 // add al r3 r2 r2 ASR 29
};
const byte kInstruction_add_al_r12_r2_r10_ASR_13[] = {
  0x02, 0xeb, 0x6a, 0x3c // add al r12 r2 r10 ASR 13
};
const byte kInstruction_add_al_r3_r2_r3_ASR_19[] = {
  0x02, 0xeb, 0xe3, 0x43 // add al r3 r2 r3 ASR 19
};
const byte kInstruction_add_al_r3_r12_r8_ASR_14[] = {
  0x0c, 0xeb, 0xa8, 0x33 // add al r3 r12 r8 ASR 14
};
const byte kInstruction_add_al_r14_r13_r9_LSR_28[] = {
  0x0d, 0xeb, 0x19, 0x7e // add al r14 r13 r9 LSR 28
};
const byte kInstruction_add_al_r6_r12_r7_ASR_32[] = {
  0x0c, 0xeb, 0x27, 0x06 // add al r6 r12 r7 ASR 32
};
const byte kInstruction_add_al_r11_r11_r12_ASR_9[] = {
  0x0b, 0xeb, 0x6c, 0x2b // add al r11 r11 r12 ASR 9
};
const byte kInstruction_add_al_r9_r11_r4_ASR_21[] = {
  0x0b, 0xeb, 0x64, 0x59 // add al r9 r11 r4 ASR 21
};
const byte kInstruction_add_al_r6_r9_r3_LSR_30[] = {
  0x09, 0xeb, 0x93, 0x76 // add al r6 r9 r3 LSR 30
};
const byte kInstruction_add_al_r6_r0_r8_ASR_22[] = {
  0x00, 0xeb, 0xa8, 0x56 // add al r6 r0 r8 ASR 22
};
const byte kInstruction_add_al_r5_r9_r11_ASR_27[] = {
  0x09, 0xeb, 0xeb, 0x65 // add al r5 r9 r11 ASR 27
};
const byte kInstruction_add_al_r4_r10_r6_LSR_2[] = {
  0x0a, 0xeb, 0x96, 0x04 // add al r4 r10 r6 LSR 2
};
const byte kInstruction_add_al_r10_r14_r11_ASR_20[] = {
  0x0e, 0xeb, 0x2b, 0x5a // add al r10 r14 r11 ASR 20
};
const byte kInstruction_add_al_r8_r13_r11_LSR_13[] = {
  0x0d, 0xeb, 0x5b, 0x38 // add al r8 r13 r11 LSR 13
};
const byte kInstruction_add_al_r7_r12_r13_LSR_11[] = {
  0x0c, 0xeb, 0xdd, 0x27 // add al r7 r12 r13 LSR 11
};
const byte kInstruction_add_al_r14_r6_r14_ASR_21[] = {
  0x06, 0xeb, 0x6e, 0x5e // add al r14 r6 r14 ASR 21
};
const byte kInstruction_add_al_r2_r2_r7_LSR_25[] = {
  0x02, 0xeb, 0x57, 0x62 // add al r2 r2 r7 LSR 25
};
const byte kInstruction_add_al_r0_r11_r5_LSR_5[] = {
  0x0b, 0xeb, 0x55, 0x10 // add al r0 r11 r5 LSR 5
};
const byte kInstruction_add_al_r1_r5_r14_LSR_19[] = {
  0x05, 0xeb, 0xde, 0x41 // add al r1 r5 r14 LSR 19
};
const byte kInstruction_add_al_r4_r14_r13_LSR_27[] = {
  0x0e, 0xeb, 0xdd, 0x64 // add al r4 r14 r13 LSR 27
};
const byte kInstruction_add_al_r13_r2_r3_ASR_24[] = {
  0x02, 0xeb, 0x23, 0x6d // add al r13 r2 r3 ASR 24
};
const byte kInstruction_add_al_r11_r1_r9_ASR_12[] = {
  0x01, 0xeb, 0x29, 0x3b // add al r11 r1 r9 ASR 12
};
const byte kInstruction_add_al_r2_r7_r13_LSR_10[] = {
  0x07, 0xeb, 0x9d, 0x22 // add al r2 r7 r13 LSR 10
};
const byte kInstruction_add_al_r4_r13_r0_ASR_3[] = {
  0x0d, 0xeb, 0xe0, 0x04 // add al r4 r13 r0 ASR 3
};
const byte kInstruction_add_al_r7_r1_r3_ASR_23[] = {
  0x01, 0xeb, 0xe3, 0x57 // add al r7 r1 r3 ASR 23
};
const byte kInstruction_add_al_r10_r13_r3_ASR_20[] = {
  0x0d, 0xeb, 0x23, 0x5a // add al r10 r13 r3 ASR 20
};
const byte kInstruction_add_al_r7_r13_r9_LSR_8[] = {
  0x0d, 0xeb, 0x19, 0x27 // add al r7 r13 r9 LSR 8
};
const byte kInstruction_add_al_r14_r14_r3_LSR_21[] = {
  0x0e, 0xeb, 0x53, 0x5e // add al r14 r14 r3 LSR 21
};
const byte kInstruction_add_al_r4_r14_r2_ASR_32[] = {
  0x0e, 0xeb, 0x22, 0x04 // add al r4 r14 r2 ASR 32
};
const byte kInstruction_add_al_r1_r4_r3_LSR_10[] = {
  0x04, 0xeb, 0x93, 0x21 // add al r1 r4 r3 LSR 10
};
const byte kInstruction_add_al_r11_r10_r9_LSR_16[] = {
  0x0a, 0xeb, 0x19, 0x4b // add al r11 r10 r9 LSR 16
};
const byte kInstruction_add_al_r9_r8_r4_LSR_5[] = {
  0x08, 0xeb, 0x54, 0x19 // add al r9 r8 r4 LSR 5
};
const byte kInstruction_add_al_r11_r8_r11_ASR_7[] = {
  0x08, 0xeb, 0xeb, 0x1b // add al r11 r8 r11 ASR 7
};
const byte kInstruction_add_al_r3_r7_r2_ASR_20[] = {
  0x07, 0xeb, 0x22, 0x53 // add al r3 r7 r2 ASR 20
};
const byte kInstruction_add_al_r9_r10_r0_ASR_1[] = {
  0x0a, 0xeb, 0x60, 0x09 // add al r9 r10 r0 ASR 1
};
const byte kInstruction_add_al_r0_r12_r10_ASR_21[] = {
  0x0c, 0xeb, 0x6a, 0x50 // add al r0 r12 r10 ASR 21
};
const byte kInstruction_add_al_r11_r4_r2_ASR_32[] = {
  0x04, 0xeb, 0x22, 0x0b // add al r11 r4 r2 ASR 32
};
const byte kInstruction_add_al_r5_r0_r2_LSR_15[] = {
  0x00, 0xeb, 0xd2, 0x35 // add al r5 r0 r2 LSR 15
};
const byte kInstruction_add_al_r8_r10_r7_ASR_14[] = {
  0x0a, 0xeb, 0xa7, 0x38 // add al r8 r10 r7 ASR 14
};
const byte kInstruction_add_al_r14_r5_r3_LSR_18[] = {
  0x05, 0xeb, 0x93, 0x4e // add al r14 r5 r3 LSR 18
};
const byte kInstruction_add_al_r2_r8_r6_ASR_6[] = {
  0x08, 0xeb, 0xa6, 0x12 // add al r2 r8 r6 ASR 6
};
const byte kInstruction_add_al_r3_r0_r4_LSR_23[] = {
  0x00, 0xeb, 0xd4, 0x53 // add al r3 r0 r4 LSR 23
};
const byte kInstruction_add_al_r3_r7_r0_LSR_13[] = {
  0x07, 0xeb, 0x50, 0x33 // add al r3 r7 r0 LSR 13
};
const byte kInstruction_add_al_r3_r4_r10_ASR_28[] = {
  0x04, 0xeb, 0x2a, 0x73 // add al r3 r4 r10 ASR 28
};
const byte kInstruction_add_al_r3_r4_r1_ASR_6[] = {
  0x04, 0xeb, 0xa1, 0x13 // add al r3 r4 r1 ASR 6
};
const byte kInstruction_add_al_r0_r3_r8_ASR_18[] = {
  0x03, 0xeb, 0xa8, 0x40 // add al r0 r3 r8 ASR 18
};
const byte kInstruction_add_al_r5_r6_r13_LSR_2[] = {
  0x06, 0xeb, 0x9d, 0x05 // add al r5 r6 r13 LSR 2
};
const byte kInstruction_add_al_r10_r11_r14_LSR_2[] = {
  0x0b, 0xeb, 0x9e, 0x0a // add al r10 r11 r14 LSR 2
};
const byte kInstruction_add_al_r10_r6_r6_ASR_17[] = {
  0x06, 0xeb, 0x66, 0x4a // add al r10 r6 r6 ASR 17
};
const byte kInstruction_add_al_r5_r2_r3_ASR_3[] = {
  0x02, 0xeb, 0xe3, 0x05 // add al r5 r2 r3 ASR 3
};
const byte kInstruction_add_al_r14_r14_r1_LSR_19[] = {
  0x0e, 0xeb, 0xd1, 0x4e // add al r14 r14 r1 LSR 19
};
const byte kInstruction_add_al_r8_r4_r7_LSR_6[] = {
  0x04, 0xeb, 0x97, 0x18 // add al r8 r4 r7 LSR 6
};
const byte kInstruction_add_al_r12_r0_r8_LSR_29[] = {
  0x00, 0xeb, 0x58, 0x7c // add al r12 r0 r8 LSR 29
};
const byte kInstruction_add_al_r9_r0_r1_ASR_29[] = {
  0x00, 0xeb, 0x61, 0x79 // add al r9 r0 r1 ASR 29
};
const byte kInstruction_add_al_r7_r13_r9_ASR_10[] = {
  0x0d, 0xeb, 0xa9, 0x27 // add al r7 r13 r9 ASR 10
};
const byte kInstruction_add_al_r9_r10_r1_ASR_26[] = {
  0x0a, 0xeb, 0xa1, 0x69 // add al r9 r10 r1 ASR 26
};
const byte kInstruction_add_al_r1_r11_r10_ASR_30[] = {
  0x0b, 0xeb, 0xaa, 0x71 // add al r1 r11 r10 ASR 30
};
const byte kInstruction_add_al_r3_r14_r6_LSR_11[] = {
  0x0e, 0xeb, 0xd6, 0x23 // add al r3 r14 r6 LSR 11
};
const TestResult kReferenceadd[] = {
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r13_r10_ASR_9),
    kInstruction_add_al_r11_r13_r10_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r5_r2_ASR_2),
    kInstruction_add_al_r7_r5_r2_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r2_r11_LSR_5),
    kInstruction_add_al_r5_r2_r11_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r6_r10_LSR_32),
    kInstruction_add_al_r14_r6_r10_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r6_r3_LSR_13),
    kInstruction_add_al_r9_r6_r3_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r4_r6_LSR_31),
    kInstruction_add_al_r14_r4_r6_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r1_r7_LSR_14),
    kInstruction_add_al_r2_r1_r7_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r9_r12_LSR_24),
    kInstruction_add_al_r2_r9_r12_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r12_r4_ASR_2),
    kInstruction_add_al_r10_r12_r4_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r10_r0_LSR_8),
    kInstruction_add_al_r6_r10_r0_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r11_r4_ASR_7),
    kInstruction_add_al_r12_r11_r4_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r4_r8_ASR_27),
    kInstruction_add_al_r9_r4_r8_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r10_r11_ASR_1),
    kInstruction_add_al_r2_r10_r11_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r2_r9_ASR_24),
    kInstruction_add_al_r0_r2_r9_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r6_r14_ASR_31),
    kInstruction_add_al_r11_r6_r14_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r14_r14_ASR_18),
    kInstruction_add_al_r2_r14_r14_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r7_r1_ASR_2),
    kInstruction_add_al_r5_r7_r1_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r14_r7_LSR_18),
    kInstruction_add_al_r1_r14_r7_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r7_r1_ASR_4),
    kInstruction_add_al_r7_r7_r1_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r5_r12_LSR_1),
    kInstruction_add_al_r14_r5_r12_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r11_r10_ASR_23),
    kInstruction_add_al_r2_r11_r10_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r0_r10_ASR_3),
    kInstruction_add_al_r5_r0_r10_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r9_ASR_6),
    kInstruction_add_al_r9_r13_r9_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r10_r13_ASR_24),
    kInstruction_add_al_r6_r10_r13_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r3_r14_LSR_30),
    kInstruction_add_al_r9_r3_r14_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r14_r11_LSR_24),
    kInstruction_add_al_r11_r14_r11_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r3_r4_ASR_7),
    kInstruction_add_al_r11_r3_r4_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r10_ASR_1),
    kInstruction_add_al_r14_r13_r10_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r9_r0_LSR_2),
    kInstruction_add_al_r0_r9_r0_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r1_r7_ASR_15),
    kInstruction_add_al_r2_r1_r7_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r14_r5_LSR_27),
    kInstruction_add_al_r8_r14_r5_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r14_r13_ASR_21),
    kInstruction_add_al_r9_r14_r13_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r14_r14_ASR_3),
    kInstruction_add_al_r11_r14_r14_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r3_r6_LSR_23),
    kInstruction_add_al_r6_r3_r6_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r8_r11_LSR_6),
    kInstruction_add_al_r14_r8_r11_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r3_r3_LSR_8),
    kInstruction_add_al_r5_r3_r3_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r6_r1_LSR_6),
    kInstruction_add_al_r12_r6_r1_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r0_r9_LSR_30),
    kInstruction_add_al_r5_r0_r9_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r9_r3_ASR_17),
    kInstruction_add_al_r4_r9_r3_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r2_r4_ASR_20),
    kInstruction_add_al_r12_r2_r4_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r9_r13_ASR_25),
    kInstruction_add_al_r2_r9_r13_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r5_r12_LSR_10),
    kInstruction_add_al_r11_r5_r12_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r13_r12_LSR_22),
    kInstruction_add_al_r4_r13_r12_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r4_r6_LSR_11),
    kInstruction_add_al_r2_r4_r6_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r4_r1_LSR_22),
    kInstruction_add_al_r8_r4_r1_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r12_r10_LSR_31),
    kInstruction_add_al_r6_r12_r10_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r0_r2_ASR_7),
    kInstruction_add_al_r10_r0_r2_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r6_r13_ASR_21),
    kInstruction_add_al_r14_r6_r13_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r14_r13_LSR_4),
    kInstruction_add_al_r7_r14_r13_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r10_r12_ASR_2),
    kInstruction_add_al_r1_r10_r12_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r2_r10_LSR_7),
    kInstruction_add_al_r0_r2_r10_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r1_r11_LSR_17),
    kInstruction_add_al_r0_r1_r11_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r13_r2_ASR_25),
    kInstruction_add_al_r4_r13_r2_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r4_r14_LSR_7),
    kInstruction_add_al_r1_r4_r14_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r8_r4_ASR_19),
    kInstruction_add_al_r5_r8_r4_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r3_r8_ASR_12),
    kInstruction_add_al_r4_r3_r8_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r4_r13_ASR_12),
    kInstruction_add_al_r2_r4_r13_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r9_r2_LSR_20),
    kInstruction_add_al_r8_r9_r2_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r6_r3_ASR_21),
    kInstruction_add_al_r10_r6_r3_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r7_r7_ASR_3),
    kInstruction_add_al_r2_r7_r7_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r7_r7_LSR_19),
    kInstruction_add_al_r8_r7_r7_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r9_r4_LSR_3),
    kInstruction_add_al_r7_r9_r4_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r7_r3_ASR_2),
    kInstruction_add_al_r1_r7_r3_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r2_r3_ASR_5),
    kInstruction_add_al_r1_r2_r3_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r4_r1_ASR_5),
    kInstruction_add_al_r12_r4_r1_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r2_r10_ASR_1),
    kInstruction_add_al_r4_r2_r10_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r5_r11_LSR_3),
    kInstruction_add_al_r10_r5_r11_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r9_r1_ASR_8),
    kInstruction_add_al_r5_r9_r1_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r11_r3_LSR_28),
    kInstruction_add_al_r6_r11_r3_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r6_LSR_22),
    kInstruction_add_al_r9_r13_r6_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r13_r1_LSR_30),
    kInstruction_add_al_r10_r13_r1_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r1_r4_ASR_26),
    kInstruction_add_al_r9_r1_r4_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r4_r4_ASR_21),
    kInstruction_add_al_r4_r4_r4_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r5_r11_ASR_19),
    kInstruction_add_al_r9_r5_r11_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r11_r5_LSR_30),
    kInstruction_add_al_r8_r11_r5_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r10_r4_LSR_23),
    kInstruction_add_al_r4_r10_r4_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r6_r2_LSR_32),
    kInstruction_add_al_r7_r6_r2_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r14_r12_LSR_7),
    kInstruction_add_al_r4_r14_r12_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r2_r9_LSR_7),
    kInstruction_add_al_r5_r2_r9_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r14_r1_ASR_6),
    kInstruction_add_al_r2_r14_r1_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r11_LSR_12),
    kInstruction_add_al_r14_r13_r11_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r8_r6_ASR_5),
    kInstruction_add_al_r8_r8_r6_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r10_r12_LSR_13),
    kInstruction_add_al_r14_r10_r12_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r6_r7_LSR_31),
    kInstruction_add_al_r3_r6_r7_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r1_r9_ASR_2),
    kInstruction_add_al_r8_r1_r9_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r12_r12_ASR_21),
    kInstruction_add_al_r9_r12_r12_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r4_r12_LSR_14),
    kInstruction_add_al_r13_r4_r12_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r11_r12_LSR_18),
    kInstruction_add_al_r2_r11_r12_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r3_r0_ASR_31),
    kInstruction_add_al_r9_r3_r0_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r6_r12_LSR_6),
    kInstruction_add_al_r13_r6_r12_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r1_r7_LSR_3),
    kInstruction_add_al_r1_r1_r7_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r13_r9_ASR_1),
    kInstruction_add_al_r0_r13_r9_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r1_r3_LSR_12),
    kInstruction_add_al_r2_r1_r3_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r6_r10_ASR_1),
    kInstruction_add_al_r12_r6_r10_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r4_r3_ASR_4),
    kInstruction_add_al_r12_r4_r3_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r0_r5_LSR_25),
    kInstruction_add_al_r7_r0_r5_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r5_r12_LSR_20),
    kInstruction_add_al_r4_r5_r12_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r5_r11_LSR_24),
    kInstruction_add_al_r3_r5_r11_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r8_r10_LSR_25),
    kInstruction_add_al_r5_r8_r10_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r9_r12_LSR_24),
    kInstruction_add_al_r11_r9_r12_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r11_r13_LSR_20),
    kInstruction_add_al_r13_r11_r13_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r4_r3_ASR_32),
    kInstruction_add_al_r12_r4_r3_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r6_r11_ASR_13),
    kInstruction_add_al_r3_r6_r11_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r9_r7_LSR_27),
    kInstruction_add_al_r13_r9_r7_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r9_r6_LSR_24),
    kInstruction_add_al_r13_r9_r6_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r13_r3_ASR_1),
    kInstruction_add_al_r6_r13_r3_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r7_r14_ASR_27),
    kInstruction_add_al_r8_r7_r14_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r8_r8_LSR_29),
    kInstruction_add_al_r8_r8_r8_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r13_r4_ASR_26),
    kInstruction_add_al_r1_r13_r4_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r2_r10_LSR_16),
    kInstruction_add_al_r3_r2_r10_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r11_r9_ASR_29),
    kInstruction_add_al_r2_r11_r9_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r9_r8_LSR_7),
    kInstruction_add_al_r12_r9_r8_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r2_r0_LSR_4),
    kInstruction_add_al_r6_r2_r0_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r2_r11_LSR_8),
    kInstruction_add_al_r12_r2_r11_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r10_r12_LSR_5),
    kInstruction_add_al_r0_r10_r12_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r2_r2_ASR_4),
    kInstruction_add_al_r2_r2_r2_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r13_r11_LSR_15),
    kInstruction_add_al_r4_r13_r11_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r2_r13_ASR_4),
    kInstruction_add_al_r4_r2_r13_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r4_r7_LSR_30),
    kInstruction_add_al_r4_r4_r7_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r8_r10_LSR_14),
    kInstruction_add_al_r4_r8_r10_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r8_r11_ASR_16),
    kInstruction_add_al_r14_r8_r11_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r8_r1_LSR_25),
    kInstruction_add_al_r0_r8_r1_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r14_ASR_3),
    kInstruction_add_al_r14_r13_r14_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r8_r13_ASR_31),
    kInstruction_add_al_r13_r8_r13_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r6_r1_LSR_28),
    kInstruction_add_al_r9_r6_r1_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r14_r1_ASR_9),
    kInstruction_add_al_r4_r14_r1_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r0_r14_LSR_7),
    kInstruction_add_al_r8_r0_r14_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r8_r12_ASR_14),
    kInstruction_add_al_r8_r8_r12_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r14_r12_ASR_19),
    kInstruction_add_al_r9_r14_r12_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r14_r11_ASR_25),
    kInstruction_add_al_r4_r14_r11_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r0_r9_ASR_13),
    kInstruction_add_al_r1_r0_r9_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r9_LSR_4),
    kInstruction_add_al_r8_r13_r9_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r4_r4_LSR_3),
    kInstruction_add_al_r2_r4_r4_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r3_LSR_8),
    kInstruction_add_al_r14_r13_r3_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r6_r3_LSR_10),
    kInstruction_add_al_r11_r6_r3_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r8_r4_ASR_31),
    kInstruction_add_al_r13_r8_r4_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r11_r0_LSR_13),
    kInstruction_add_al_r8_r11_r0_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r5_r10_ASR_19),
    kInstruction_add_al_r10_r5_r10_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r4_r5_ASR_2),
    kInstruction_add_al_r13_r4_r5_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r4_r10_LSR_3),
    kInstruction_add_al_r8_r4_r10_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r7_r3_LSR_6),
    kInstruction_add_al_r13_r7_r3_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r1_r8_LSR_1),
    kInstruction_add_al_r6_r1_r8_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r13_r9_LSR_31),
    kInstruction_add_al_r5_r13_r9_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r8_r0_ASR_19),
    kInstruction_add_al_r11_r8_r0_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r6_r8_LSR_25),
    kInstruction_add_al_r14_r6_r8_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r6_r7_ASR_28),
    kInstruction_add_al_r10_r6_r7_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r2_r9_LSR_12),
    kInstruction_add_al_r5_r2_r9_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r2_r6_ASR_18),
    kInstruction_add_al_r1_r2_r6_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r13_r11_ASR_14),
    kInstruction_add_al_r10_r13_r11_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r8_r8_LSR_14),
    kInstruction_add_al_r6_r8_r8_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r14_r11_ASR_18),
    kInstruction_add_al_r7_r14_r11_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r11_r2_LSR_13),
    kInstruction_add_al_r3_r11_r2_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r7_r6_ASR_10),
    kInstruction_add_al_r14_r7_r6_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r5_r7_ASR_12),
    kInstruction_add_al_r6_r5_r7_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r2_r9_ASR_13),
    kInstruction_add_al_r5_r2_r9_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r13_r3_LSR_14),
    kInstruction_add_al_r12_r13_r3_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r4_r0_ASR_23),
    kInstruction_add_al_r10_r4_r0_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r12_r2_LSR_18),
    kInstruction_add_al_r10_r12_r2_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r10_r14_ASR_18),
    kInstruction_add_al_r4_r10_r14_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r0_r1_LSR_7),
    kInstruction_add_al_r13_r0_r1_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r3_r13_LSR_16),
    kInstruction_add_al_r3_r3_r13_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r4_r4_ASR_19),
    kInstruction_add_al_r7_r4_r4_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r7_r4_ASR_13),
    kInstruction_add_al_r6_r7_r4_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r10_r11_LSR_14),
    kInstruction_add_al_r8_r10_r11_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r0_r1_ASR_32),
    kInstruction_add_al_r0_r0_r1_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r12_r0_LSR_17),
    kInstruction_add_al_r10_r12_r0_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r5_r12_ASR_8),
    kInstruction_add_al_r2_r5_r12_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r3_r11_LSR_1),
    kInstruction_add_al_r4_r3_r11_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r13_r12_LSR_22),
    kInstruction_add_al_r12_r13_r12_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r11_LSR_12),
    kInstruction_add_al_r8_r13_r11_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r11_r3_LSR_27),
    kInstruction_add_al_r9_r11_r3_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r9_r10_ASR_21),
    kInstruction_add_al_r8_r9_r10_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r3_r0_LSR_8),
    kInstruction_add_al_r10_r3_r0_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r2_r6_LSR_32),
    kInstruction_add_al_r9_r2_r6_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r0_r9_ASR_24),
    kInstruction_add_al_r9_r0_r9_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r10_r7_LSR_7),
    kInstruction_add_al_r0_r10_r7_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r11_r12_LSR_14),
    kInstruction_add_al_r7_r11_r12_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r10_r13_ASR_29),
    kInstruction_add_al_r12_r10_r13_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r14_r3_LSR_5),
    kInstruction_add_al_r2_r14_r3_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r3_r12_ASR_19),
    kInstruction_add_al_r14_r3_r12_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r12_r11_ASR_31),
    kInstruction_add_al_r12_r12_r11_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r3_r2_ASR_4),
    kInstruction_add_al_r0_r3_r2_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r2_r11_ASR_9),
    kInstruction_add_al_r13_r2_r11_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r14_r9_LSR_13),
    kInstruction_add_al_r12_r14_r9_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r3_r3_ASR_28),
    kInstruction_add_al_r14_r3_r3_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r5_r12_LSR_19),
    kInstruction_add_al_r12_r5_r12_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r1_LSR_14),
    kInstruction_add_al_r9_r13_r1_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r3_r1_LSR_11),
    kInstruction_add_al_r5_r3_r1_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r14_r5_ASR_22),
    kInstruction_add_al_r0_r14_r5_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r9_r8_ASR_12),
    kInstruction_add_al_r8_r9_r8_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r0_r13_LSR_15),
    kInstruction_add_al_r9_r0_r13_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r5_r14_ASR_9),
    kInstruction_add_al_r9_r5_r14_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r13_LSR_16),
    kInstruction_add_al_r9_r13_r13_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r0_r8_ASR_17),
    kInstruction_add_al_r7_r0_r8_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r13_r14_ASR_30),
    kInstruction_add_al_r10_r13_r14_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r10_r4_LSR_8),
    kInstruction_add_al_r7_r10_r4_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r5_r1_ASR_2),
    kInstruction_add_al_r10_r5_r1_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r10_r2_LSR_10),
    kInstruction_add_al_r4_r10_r2_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r5_r0_LSR_22),
    kInstruction_add_al_r3_r5_r0_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r11_r12_LSR_22),
    kInstruction_add_al_r13_r11_r12_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r8_r6_LSR_6),
    kInstruction_add_al_r0_r8_r6_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r4_r1_LSR_30),
    kInstruction_add_al_r13_r4_r1_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r9_r12_ASR_20),
    kInstruction_add_al_r13_r9_r12_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r5_r10_ASR_2),
    kInstruction_add_al_r0_r5_r10_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r4_r0_ASR_13),
    kInstruction_add_al_r10_r4_r0_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r3_r0_LSR_16),
    kInstruction_add_al_r12_r3_r0_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r11_r14_ASR_25),
    kInstruction_add_al_r7_r11_r14_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r9_r12_ASR_31),
    kInstruction_add_al_r8_r9_r12_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r11_r8_LSR_26),
    kInstruction_add_al_r14_r11_r8_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r3_r6_ASR_31),
    kInstruction_add_al_r8_r3_r6_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r4_r5_ASR_9),
    kInstruction_add_al_r10_r4_r5_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r4_r6_LSR_31),
    kInstruction_add_al_r9_r4_r6_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r6_r12_LSR_32),
    kInstruction_add_al_r12_r6_r12_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r8_r9_LSR_15),
    kInstruction_add_al_r5_r8_r9_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r7_r0_LSR_4),
    kInstruction_add_al_r1_r7_r0_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r5_r3_LSR_11),
    kInstruction_add_al_r14_r5_r3_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r5_r11_ASR_2),
    kInstruction_add_al_r0_r5_r11_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r13_r7_ASR_4),
    kInstruction_add_al_r11_r13_r7_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r12_LSR_7),
    kInstruction_add_al_r8_r13_r12_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r11_r2_ASR_28),
    kInstruction_add_al_r2_r11_r2_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r14_r11_LSR_14),
    kInstruction_add_al_r9_r14_r11_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r12_r4_ASR_24),
    kInstruction_add_al_r5_r12_r4_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r3_LSR_19),
    kInstruction_add_al_r9_r13_r3_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r3_r3_ASR_25),
    kInstruction_add_al_r6_r3_r3_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r6_r6_LSR_16),
    kInstruction_add_al_r13_r6_r6_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r9_r5_ASR_30),
    kInstruction_add_al_r0_r9_r5_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r9_r0_LSR_5),
    kInstruction_add_al_r9_r9_r0_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r5_r14_LSR_12),
    kInstruction_add_al_r0_r5_r14_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r12_r7_ASR_7),
    kInstruction_add_al_r14_r12_r7_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r6_ASR_27),
    kInstruction_add_al_r8_r13_r6_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r6_r13_LSR_24),
    kInstruction_add_al_r12_r6_r13_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r10_r6_ASR_32),
    kInstruction_add_al_r7_r10_r6_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r12_r13_ASR_8),
    kInstruction_add_al_r6_r12_r13_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r0_r8_LSR_19),
    kInstruction_add_al_r13_r0_r8_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r9_r10_LSR_20),
    kInstruction_add_al_r10_r9_r10_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r7_r2_LSR_25),
    kInstruction_add_al_r5_r7_r2_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r6_r0_LSR_15),
    kInstruction_add_al_r2_r6_r0_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r6_r8_LSR_21),
    kInstruction_add_al_r12_r6_r8_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r2_LSR_29),
    kInstruction_add_al_r14_r13_r2_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r13_r0_LSR_21),
    kInstruction_add_al_r1_r13_r0_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r7_r8_ASR_13),
    kInstruction_add_al_r6_r7_r8_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r2_r10_ASR_8),
    kInstruction_add_al_r13_r2_r10_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r13_r7_LSR_2),
    kInstruction_add_al_r5_r13_r7_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r3_r2_LSR_17),
    kInstruction_add_al_r0_r3_r2_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r8_r9_LSR_3),
    kInstruction_add_al_r1_r8_r9_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r3_r1_LSR_29),
    kInstruction_add_al_r11_r3_r1_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r2_r11_LSR_17),
    kInstruction_add_al_r2_r2_r11_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r14_r11_LSR_22),
    kInstruction_add_al_r7_r14_r11_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r7_r14_LSR_17),
    kInstruction_add_al_r8_r7_r14_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r2_r7_ASR_32),
    kInstruction_add_al_r14_r2_r7_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r6_r9_ASR_13),
    kInstruction_add_al_r0_r6_r9_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r5_r4_ASR_24),
    kInstruction_add_al_r3_r5_r4_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r10_r6_ASR_1),
    kInstruction_add_al_r10_r10_r6_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r9_r4_ASR_5),
    kInstruction_add_al_r8_r9_r4_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r0_r6_LSR_25),
    kInstruction_add_al_r3_r0_r6_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r7_r12_ASR_11),
    kInstruction_add_al_r12_r7_r12_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r9_r7_ASR_2),
    kInstruction_add_al_r10_r9_r7_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r13_r5_ASR_2),
    kInstruction_add_al_r13_r13_r5_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r3_r2_ASR_5),
    kInstruction_add_al_r11_r3_r2_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r8_r8_ASR_10),
    kInstruction_add_al_r0_r8_r8_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r12_r12_ASR_19),
    kInstruction_add_al_r10_r12_r12_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r6_r0_LSR_10),
    kInstruction_add_al_r2_r6_r0_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r8_r8_ASR_15),
    kInstruction_add_al_r11_r8_r8_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r14_r1_LSR_14),
    kInstruction_add_al_r14_r14_r1_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r8_r12_ASR_21),
    kInstruction_add_al_r9_r8_r12_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r14_r12_ASR_9),
    kInstruction_add_al_r14_r14_r12_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r0_r3_ASR_22),
    kInstruction_add_al_r0_r0_r3_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r7_r13_LSR_16),
    kInstruction_add_al_r9_r7_r13_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r1_r5_LSR_28),
    kInstruction_add_al_r8_r1_r5_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r2_r11_LSR_21),
    kInstruction_add_al_r0_r2_r11_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r12_r8_LSR_25),
    kInstruction_add_al_r5_r12_r8_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r5_r6_ASR_5),
    kInstruction_add_al_r9_r5_r6_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r0_r7_ASR_13),
    kInstruction_add_al_r0_r0_r7_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r10_r7_ASR_10),
    kInstruction_add_al_r2_r10_r7_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r8_r14_ASR_32),
    kInstruction_add_al_r13_r8_r14_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r2_r9_ASR_30),
    kInstruction_add_al_r3_r2_r9_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r0_r14_ASR_6),
    kInstruction_add_al_r11_r0_r14_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r10_r2_ASR_18),
    kInstruction_add_al_r13_r10_r2_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r1_ASR_18),
    kInstruction_add_al_r8_r13_r1_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r4_r3_LSR_19),
    kInstruction_add_al_r10_r4_r3_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r2_r9_ASR_15),
    kInstruction_add_al_r2_r2_r9_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r4_r8_LSR_28),
    kInstruction_add_al_r6_r4_r8_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r9_r6_LSR_27),
    kInstruction_add_al_r14_r9_r6_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r14_r8_LSR_18),
    kInstruction_add_al_r3_r14_r8_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r1_r14_LSR_2),
    kInstruction_add_al_r4_r1_r14_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r9_r6_ASR_16),
    kInstruction_add_al_r13_r9_r6_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r1_r9_ASR_29),
    kInstruction_add_al_r4_r1_r9_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r3_r2_LSR_23),
    kInstruction_add_al_r4_r3_r2_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r8_r0_LSR_19),
    kInstruction_add_al_r11_r8_r0_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r10_r4_ASR_29),
    kInstruction_add_al_r6_r10_r4_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r2_r5_ASR_25),
    kInstruction_add_al_r8_r2_r5_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r10_r14_LSR_25),
    kInstruction_add_al_r3_r10_r14_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r9_r0_LSR_32),
    kInstruction_add_al_r4_r9_r0_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r10_r1_ASR_8),
    kInstruction_add_al_r14_r10_r1_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r10_r1_LSR_4),
    kInstruction_add_al_r10_r10_r1_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r2_r9_ASR_23),
    kInstruction_add_al_r10_r2_r9_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r2_r7_LSR_30),
    kInstruction_add_al_r12_r2_r7_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r4_r9_ASR_20),
    kInstruction_add_al_r13_r4_r9_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r13_r2_LSR_29),
    kInstruction_add_al_r12_r13_r2_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r8_r13_ASR_12),
    kInstruction_add_al_r14_r8_r13_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r14_r11_ASR_18),
    kInstruction_add_al_r11_r14_r11_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r10_r1_LSR_3),
    kInstruction_add_al_r11_r10_r1_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r2_r0_LSR_27),
    kInstruction_add_al_r6_r2_r0_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r6_r12_ASR_6),
    kInstruction_add_al_r13_r6_r12_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r2_r3_ASR_21),
    kInstruction_add_al_r9_r2_r3_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r9_r4_LSR_16),
    kInstruction_add_al_r2_r9_r4_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r13_r10_ASR_23),
    kInstruction_add_al_r10_r13_r10_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r10_LSR_20),
    kInstruction_add_al_r8_r13_r10_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r7_r7_ASR_17),
    kInstruction_add_al_r0_r7_r7_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r5_r9_ASR_24),
    kInstruction_add_al_r2_r5_r9_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r9_r7_ASR_16),
    kInstruction_add_al_r1_r9_r7_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r1_r7_LSR_26),
    kInstruction_add_al_r4_r1_r7_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r4_r10_LSR_26),
    kInstruction_add_al_r6_r4_r10_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r5_r7_ASR_1),
    kInstruction_add_al_r9_r5_r7_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r3_r5_LSR_8),
    kInstruction_add_al_r5_r3_r5_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r6_r8_LSR_28),
    kInstruction_add_al_r7_r6_r8_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r5_r12_ASR_23),
    kInstruction_add_al_r3_r5_r12_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r14_r9_LSR_28),
    kInstruction_add_al_r3_r14_r9_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r5_r3_LSR_21),
    kInstruction_add_al_r14_r5_r3_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r0_r13_LSR_23),
    kInstruction_add_al_r11_r0_r13_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r13_r7_LSR_15),
    kInstruction_add_al_r13_r13_r7_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r10_r8_LSR_24),
    kInstruction_add_al_r6_r10_r8_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r11_r11_ASR_28),
    kInstruction_add_al_r8_r11_r11_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r1_r1_LSR_26),
    kInstruction_add_al_r9_r1_r1_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r4_r14_LSR_2),
    kInstruction_add_al_r2_r4_r14_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r7_r2_ASR_19),
    kInstruction_add_al_r4_r7_r2_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r1_r7_ASR_23),
    kInstruction_add_al_r9_r1_r7_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r7_r11_ASR_7),
    kInstruction_add_al_r4_r7_r11_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r9_r5_ASR_32),
    kInstruction_add_al_r7_r9_r5_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r6_r6_ASR_11),
    kInstruction_add_al_r14_r6_r6_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r5_r14_ASR_32),
    kInstruction_add_al_r14_r5_r14_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r2_r13_LSR_15),
    kInstruction_add_al_r9_r2_r13_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r8_r3_LSR_15),
    kInstruction_add_al_r13_r8_r3_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r0_r2_ASR_10),
    kInstruction_add_al_r14_r0_r2_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r6_r5_LSR_3),
    kInstruction_add_al_r9_r6_r5_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r10_r12_LSR_13),
    kInstruction_add_al_r11_r10_r12_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r11_r9_LSR_11),
    kInstruction_add_al_r7_r11_r9_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r9_r9_ASR_10),
    kInstruction_add_al_r3_r9_r9_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r14_r3_LSR_25),
    kInstruction_add_al_r12_r14_r3_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r1_r11_ASR_7),
    kInstruction_add_al_r13_r1_r11_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r9_r5_ASR_2),
    kInstruction_add_al_r12_r9_r5_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r13_r7_ASR_12),
    kInstruction_add_al_r6_r13_r7_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r1_r5_LSR_16),
    kInstruction_add_al_r5_r1_r5_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r11_r13_LSR_22),
    kInstruction_add_al_r0_r11_r13_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r8_r1_ASR_25),
    kInstruction_add_al_r7_r8_r1_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r13_r9_LSR_11),
    kInstruction_add_al_r2_r13_r9_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r9_r11_ASR_17),
    kInstruction_add_al_r4_r9_r11_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r0_r4_ASR_13),
    kInstruction_add_al_r6_r0_r4_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r0_r14_LSR_23),
    kInstruction_add_al_r9_r0_r14_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r11_r5_ASR_17),
    kInstruction_add_al_r14_r11_r5_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r14_r13_ASR_4),
    kInstruction_add_al_r6_r14_r13_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r12_r7_ASR_31),
    kInstruction_add_al_r14_r12_r7_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r10_r12_ASR_1),
    kInstruction_add_al_r11_r10_r12_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r11_r12_ASR_25),
    kInstruction_add_al_r14_r11_r12_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r13_r1_ASR_1),
    kInstruction_add_al_r2_r13_r1_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r2_r3_LSR_29),
    kInstruction_add_al_r9_r2_r3_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r7_r6_ASR_20),
    kInstruction_add_al_r1_r7_r6_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r3_LSR_2),
    kInstruction_add_al_r9_r13_r3_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r12_r5_ASR_24),
    kInstruction_add_al_r8_r12_r5_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r5_r14_LSR_1),
    kInstruction_add_al_r12_r5_r14_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r4_r9_ASR_30),
    kInstruction_add_al_r13_r4_r9_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r2_r11_ASR_28),
    kInstruction_add_al_r12_r2_r11_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r2_r11_LSR_26),
    kInstruction_add_al_r8_r2_r11_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r0_r2_ASR_21),
    kInstruction_add_al_r0_r0_r2_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r10_r14_LSR_22),
    kInstruction_add_al_r7_r10_r14_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r1_r4_ASR_18),
    kInstruction_add_al_r3_r1_r4_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r14_r3_ASR_32),
    kInstruction_add_al_r8_r14_r3_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r9_r8_ASR_4),
    kInstruction_add_al_r4_r9_r8_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r2_r4_ASR_14),
    kInstruction_add_al_r7_r2_r4_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r1_r9_ASR_9),
    kInstruction_add_al_r12_r1_r9_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r5_r0_ASR_11),
    kInstruction_add_al_r3_r5_r0_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r9_r0_LSR_10),
    kInstruction_add_al_r14_r9_r0_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r6_ASR_27),
    kInstruction_add_al_r14_r13_r6_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r8_r1_LSR_27),
    kInstruction_add_al_r13_r8_r1_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r0_r7_LSR_31),
    kInstruction_add_al_r7_r0_r7_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r8_r7_ASR_27),
    kInstruction_add_al_r5_r8_r7_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r3_r10_ASR_24),
    kInstruction_add_al_r12_r3_r10_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r14_r5_LSR_20),
    kInstruction_add_al_r14_r14_r5_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r12_r7_LSR_32),
    kInstruction_add_al_r0_r12_r7_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r3_r6_ASR_17),
    kInstruction_add_al_r2_r3_r6_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r8_r13_ASR_27),
    kInstruction_add_al_r11_r8_r13_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r12_r4_LSR_24),
    kInstruction_add_al_r13_r12_r4_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r3_r0_ASR_26),
    kInstruction_add_al_r3_r3_r0_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r0_r5_ASR_26),
    kInstruction_add_al_r10_r0_r5_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r9_r7_LSR_6),
    kInstruction_add_al_r5_r9_r7_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r4_r9_ASR_8),
    kInstruction_add_al_r12_r4_r9_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r0_r13_LSR_16),
    kInstruction_add_al_r4_r0_r13_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r2_r2_LSR_6),
    kInstruction_add_al_r11_r2_r2_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r4_r3_ASR_11),
    kInstruction_add_al_r12_r4_r3_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r10_r12_ASR_22),
    kInstruction_add_al_r0_r10_r12_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r2_r12_LSR_16),
    kInstruction_add_al_r12_r2_r12_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r2_r8_ASR_14),
    kInstruction_add_al_r2_r2_r8_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r1_r3_LSR_2),
    kInstruction_add_al_r9_r1_r3_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r0_r6_ASR_15),
    kInstruction_add_al_r7_r0_r6_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r2_r12_LSR_17),
    kInstruction_add_al_r11_r2_r12_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r7_r7_ASR_19),
    kInstruction_add_al_r3_r7_r7_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r13_r1_LSR_29),
    kInstruction_add_al_r9_r13_r1_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r0_r2_LSR_2),
    kInstruction_add_al_r1_r0_r2_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r10_r2_ASR_12),
    kInstruction_add_al_r14_r10_r2_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r14_r11_ASR_27),
    kInstruction_add_al_r7_r14_r11_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r8_r13_ASR_17),
    kInstruction_add_al_r9_r8_r13_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r14_r8_LSR_11),
    kInstruction_add_al_r6_r14_r8_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r3_r9_ASR_31),
    kInstruction_add_al_r5_r3_r9_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r4_r1_ASR_29),
    kInstruction_add_al_r5_r4_r1_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r5_r10_ASR_25),
    kInstruction_add_al_r6_r5_r10_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r8_r14_ASR_32),
    kInstruction_add_al_r1_r8_r14_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r3_r5_ASR_4),
    kInstruction_add_al_r0_r3_r5_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r6_r1_ASR_5),
    kInstruction_add_al_r8_r6_r1_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r9_r14_ASR_25),
    kInstruction_add_al_r14_r9_r14_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r10_r0_ASR_18),
    kInstruction_add_al_r2_r10_r0_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r14_r0_LSR_23),
    kInstruction_add_al_r12_r14_r0_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r13_r14_LSR_25),
    kInstruction_add_al_r5_r13_r14_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r11_r10_ASR_18),
    kInstruction_add_al_r13_r11_r10_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r9_r4_LSR_22),
    kInstruction_add_al_r13_r9_r4_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r12_r5_LSR_12),
    kInstruction_add_al_r10_r12_r5_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r1_r2_ASR_28),
    kInstruction_add_al_r0_r1_r2_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r5_r5_LSR_4),
    kInstruction_add_al_r13_r5_r5_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r3_r10_LSR_18),
    kInstruction_add_al_r1_r3_r10_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r6_r4_LSR_4),
    kInstruction_add_al_r2_r6_r4_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r3_r10_LSR_4),
    kInstruction_add_al_r0_r3_r10_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r2_r8_LSR_30),
    kInstruction_add_al_r14_r2_r8_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r12_r10_ASR_18),
    kInstruction_add_al_r10_r12_r10_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r4_r2_LSR_31),
    kInstruction_add_al_r13_r4_r2_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r11_r14_LSR_5),
    kInstruction_add_al_r10_r11_r14_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r1_r6_ASR_8),
    kInstruction_add_al_r3_r1_r6_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r14_r2_ASR_10),
    kInstruction_add_al_r7_r14_r2_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r10_r8_ASR_8),
    kInstruction_add_al_r8_r10_r8_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r10_r4_ASR_21),
    kInstruction_add_al_r7_r10_r4_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r3_r3_ASR_6),
    kInstruction_add_al_r6_r3_r3_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r8_r6_ASR_20),
    kInstruction_add_al_r1_r8_r6_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r6_r0_LSR_12),
    kInstruction_add_al_r14_r6_r0_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r1_r14_LSR_19),
    kInstruction_add_al_r8_r1_r14_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r7_r8_LSR_22),
    kInstruction_add_al_r6_r7_r8_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r0_r11_LSR_8),
    kInstruction_add_al_r9_r0_r11_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r3_r2_LSR_6),
    kInstruction_add_al_r10_r3_r2_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r14_r0_ASR_12),
    kInstruction_add_al_r2_r14_r0_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r3_r5_LSR_22),
    kInstruction_add_al_r6_r3_r5_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r13_r9_LSR_12),
    kInstruction_add_al_r2_r13_r9_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r5_r2_LSR_5),
    kInstruction_add_al_r14_r5_r2_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r10_r12_LSR_32),
    kInstruction_add_al_r4_r10_r12_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r12_r2_ASR_1),
    kInstruction_add_al_r1_r12_r2_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r11_r3_ASR_27),
    kInstruction_add_al_r7_r11_r3_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r2_r2_ASR_29),
    kInstruction_add_al_r3_r2_r2_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r2_r10_ASR_13),
    kInstruction_add_al_r12_r2_r10_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r2_r3_ASR_19),
    kInstruction_add_al_r3_r2_r3_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r12_r8_ASR_14),
    kInstruction_add_al_r3_r12_r8_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r13_r9_LSR_28),
    kInstruction_add_al_r14_r13_r9_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r12_r7_ASR_32),
    kInstruction_add_al_r6_r12_r7_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r11_r12_ASR_9),
    kInstruction_add_al_r11_r11_r12_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r11_r4_ASR_21),
    kInstruction_add_al_r9_r11_r4_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r9_r3_LSR_30),
    kInstruction_add_al_r6_r9_r3_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r6_r0_r8_ASR_22),
    kInstruction_add_al_r6_r0_r8_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r9_r11_ASR_27),
    kInstruction_add_al_r5_r9_r11_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r10_r6_LSR_2),
    kInstruction_add_al_r4_r10_r6_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r14_r11_ASR_20),
    kInstruction_add_al_r10_r14_r11_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r13_r11_LSR_13),
    kInstruction_add_al_r8_r13_r11_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r12_r13_LSR_11),
    kInstruction_add_al_r7_r12_r13_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r6_r14_ASR_21),
    kInstruction_add_al_r14_r6_r14_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r2_r7_LSR_25),
    kInstruction_add_al_r2_r2_r7_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r11_r5_LSR_5),
    kInstruction_add_al_r0_r11_r5_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r5_r14_LSR_19),
    kInstruction_add_al_r1_r5_r14_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r14_r13_LSR_27),
    kInstruction_add_al_r4_r14_r13_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r13_r2_r3_ASR_24),
    kInstruction_add_al_r13_r2_r3_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r1_r9_ASR_12),
    kInstruction_add_al_r11_r1_r9_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r7_r13_LSR_10),
    kInstruction_add_al_r2_r7_r13_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r13_r0_ASR_3),
    kInstruction_add_al_r4_r13_r0_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r1_r3_ASR_23),
    kInstruction_add_al_r7_r1_r3_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r13_r3_ASR_20),
    kInstruction_add_al_r10_r13_r3_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r13_r9_LSR_8),
    kInstruction_add_al_r7_r13_r9_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r14_r3_LSR_21),
    kInstruction_add_al_r14_r14_r3_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r4_r14_r2_ASR_32),
    kInstruction_add_al_r4_r14_r2_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r4_r3_LSR_10),
    kInstruction_add_al_r1_r4_r3_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r10_r9_LSR_16),
    kInstruction_add_al_r11_r10_r9_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r8_r4_LSR_5),
    kInstruction_add_al_r9_r8_r4_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r8_r11_ASR_7),
    kInstruction_add_al_r11_r8_r11_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r7_r2_ASR_20),
    kInstruction_add_al_r3_r7_r2_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r10_r0_ASR_1),
    kInstruction_add_al_r9_r10_r0_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r12_r10_ASR_21),
    kInstruction_add_al_r0_r12_r10_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r11_r4_r2_ASR_32),
    kInstruction_add_al_r11_r4_r2_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r0_r2_LSR_15),
    kInstruction_add_al_r5_r0_r2_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r10_r7_ASR_14),
    kInstruction_add_al_r8_r10_r7_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r5_r3_LSR_18),
    kInstruction_add_al_r14_r5_r3_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r2_r8_r6_ASR_6),
    kInstruction_add_al_r2_r8_r6_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r0_r4_LSR_23),
    kInstruction_add_al_r3_r0_r4_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r7_r0_LSR_13),
    kInstruction_add_al_r3_r7_r0_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r4_r10_ASR_28),
    kInstruction_add_al_r3_r4_r10_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r4_r1_ASR_6),
    kInstruction_add_al_r3_r4_r1_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r0_r3_r8_ASR_18),
    kInstruction_add_al_r0_r3_r8_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r6_r13_LSR_2),
    kInstruction_add_al_r5_r6_r13_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r11_r14_LSR_2),
    kInstruction_add_al_r10_r11_r14_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r10_r6_r6_ASR_17),
    kInstruction_add_al_r10_r6_r6_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r5_r2_r3_ASR_3),
    kInstruction_add_al_r5_r2_r3_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r14_r14_r1_LSR_19),
    kInstruction_add_al_r14_r14_r1_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r8_r4_r7_LSR_6),
    kInstruction_add_al_r8_r4_r7_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r12_r0_r8_LSR_29),
    kInstruction_add_al_r12_r0_r8_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r0_r1_ASR_29),
    kInstruction_add_al_r9_r0_r1_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r7_r13_r9_ASR_10),
    kInstruction_add_al_r7_r13_r9_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r9_r10_r1_ASR_26),
    kInstruction_add_al_r9_r10_r1_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r1_r11_r10_ASR_30),
    kInstruction_add_al_r1_r11_r10_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_add_al_r3_r14_r6_LSR_11),
    kInstruction_add_al_r3_r14_r6_LSR_11,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO32_ADD_T32_H_
